# -*- coding: utf-8 -*-
info = {
    "%%aja": {
        "0": "ная;",
        "(1, 'inf')": "'а =%spellout-ordinal-feminine=;"
    },
    "%%fractions-feminine": {
        "(10, 99)": "<%spellout-cardinal-feminine< $(cardinal,one{десятая}other{десятых})$;",
        "(100, 999)": "<%spellout-cardinal-feminine< $(cardinal,one{сотая}other{сотых})$;",
        "(1000, 9999)": "<%spellout-cardinal-feminine< $(cardinal,one{тысячная}other{тысячных})$;",
        "(10000, 99999)": "<%spellout-cardinal-feminine< $(cardinal,one{десятитысячная}other{десятитысячных})$;",
        "(100000, 999999)": "<%spellout-cardinal-feminine< $(cardinal,one{стотысячная}other{стотысячных})$;",
        "(1000000, 9999999)": "<%spellout-cardinal-feminine< $(cardinal,one{миллионная}other{миллионных})$;",
        "(10000000, 99999999)": "<%spellout-cardinal-feminine< $(cardinal,one{десятимиллионная}other{десятимиллионных})$;",
        "(100000000, 999999999)": "<%spellout-cardinal-feminine< $(cardinal,one{стомиллионная}other{стомиллионных})$;",
        "(1000000000, 9999999999)": "<%spellout-cardinal-feminine< $(cardinal,one{миллиардная}other{миллиардных})$;",
        "(10000000000, 99999999999)": "<%spellout-cardinal-feminine< $(cardinal,one{десятимиллиардная}other{десятимиллиардных})$;",
        "(100000000000, 999999999999)": "<%spellout-cardinal-feminine< $(cardinal,one{стомиллиардная}other{стомиллиардных})$;",
        "(1000000000000, 'inf')": "<0<;"
    },
    "%%fractions-feminine-ablative": {
        "(10, 99)": "<%spellout-cardinal-feminine-ablative< $(cardinal,one{десятой}other{десятыми})$;",
        "(100, 999)": "<%spellout-cardinal-feminine-ablative< $(cardinal,one{сотой}other{сотыми})$;",
        "(1000, 9999)": "<%spellout-cardinal-feminine-ablative< $(cardinal,one{тысячной}other{тысячными})$;",
        "(10000, 99999)": "<%spellout-cardinal-feminine-ablative< $(cardinal,one{десятитысячной}other{десятитысячными})$;",
        "(100000, 999999)": "<%spellout-cardinal-feminine-ablative< $(cardinal,one{стотысячной}other{стотысячными})$;",
        "(1000000, 9999999)": "<%spellout-cardinal-feminine-ablative< $(cardinal,one{миллионной}other{миллионными})$;",
        "(10000000, 99999999)": "<%spellout-cardinal-feminine-ablative< $(cardinal,one{десятимиллионной}other{десятимиллионными})$;",
        "(100000000, 999999999)": "<%spellout-cardinal-feminine-ablative< $(cardinal,one{стомиллионной}other{стомиллионными})$;",
        "(1000000000, 9999999999)": "<%spellout-cardinal-feminine-ablative< $(cardinal,one{миллиардной}other{миллиардными})$;",
        "(10000000000, 99999999999)": "<%spellout-cardinal-feminine-ablative< $(cardinal,one{десятимиллиардной}other{десятимиллиардными})$;",
        "(100000000000, 999999999999)": "<%spellout-cardinal-feminine-ablative< $(cardinal,one{стомиллиардной}other{стомиллиардными})$;",
        "(1000000000000, 'inf')": "<0<;"
    },
    "%%fractions-feminine-accusative": {
        "(10, 99)": "<%spellout-cardinal-feminine-accusative< $(cardinal,one{десятую}other{десятых})$;",
        "(100, 999)": "<%spellout-cardinal-feminine-accusative< $(cardinal,one{сотую}other{сотых})$;",
        "(1000, 9999)": "<%spellout-cardinal-feminine-accusative< $(cardinal,one{тысячную}other{тысячных})$;",
        "(10000, 99999)": "<%spellout-cardinal-feminine-accusative< $(cardinal,one{десятитысячную}other{десятитысячных})$;",
        "(100000, 999999)": "<%spellout-cardinal-feminine-accusative< $(cardinal,one{стотысячную}other{стотысячных})$;",
        "(1000000, 9999999)": "<%spellout-cardinal-feminine-accusative< $(cardinal,one{миллионную}other{миллионных})$;",
        "(10000000, 99999999)": "<%spellout-cardinal-feminine-accusative< $(cardinal,one{десятимиллионную}other{десятимиллионных})$;",
        "(100000000, 999999999)": "<%spellout-cardinal-feminine-accusative< $(cardinal,one{стомиллионную}other{стомиллионных})$;",
        "(1000000000, 9999999999)": "<%spellout-cardinal-feminine-accusative< $(cardinal,one{миллиардную}other{миллиардных})$;",
        "(10000000000, 99999999999)": "<%spellout-cardinal-feminine-accusative< $(cardinal,one{десятимиллиардную}other{десятимиллиардных})$;",
        "(100000000000, 999999999999)": "<%spellout-cardinal-feminine-accusative< $(cardinal,one{стомиллиардную}other{стомиллиардных})$;",
        "(1000000000000, 'inf')": "<0<;"
    },
    "%%fractions-feminine-dative": {
        "(10, 99)": "<%spellout-cardinal-feminine-dative< $(cardinal,one{десятой}other{десятым})$;",
        "(100, 999)": "<%spellout-cardinal-feminine-dative< $(cardinal,one{сотой}other{сотым})$;",
        "(1000, 9999)": "<%spellout-cardinal-feminine-dative< $(cardinal,one{тысячной}other{тысячным})$;",
        "(10000, 99999)": "<%spellout-cardinal-feminine-dative< $(cardinal,one{десятитысячной}other{десятитысячным})$;",
        "(100000, 999999)": "<%spellout-cardinal-feminine-dative< $(cardinal,one{стотысячной}other{стотысячным})$;",
        "(1000000, 9999999)": "<%spellout-cardinal-feminine-dative< $(cardinal,one{миллионной}other{миллионным})$;",
        "(10000000, 99999999)": "<%spellout-cardinal-feminine-dative< $(cardinal,one{десятимиллионной}other{десятимиллионным})$;",
        "(100000000, 999999999)": "<%spellout-cardinal-feminine-dative< $(cardinal,one{стомиллионной}other{стомиллионным})$;",
        "(1000000000, 9999999999)": "<%spellout-cardinal-feminine-dative< $(cardinal,one{миллиардной}other{миллиардным})$;",
        "(10000000000, 99999999999)": "<%spellout-cardinal-feminine-dative< $(cardinal,one{десятимиллиардной}other{десятимиллиардным})$;",
        "(100000000000, 999999999999)": "<%spellout-cardinal-feminine-dative< $(cardinal,one{стомиллиардной}other{стомиллиардным})$;",
        "(1000000000000, 'inf')": "<0<;"
    },
    "%%fractions-feminine-genitive": {
        "(10, 99)": "<%spellout-cardinal-feminine-genitive< $(cardinal,one{десятой}other{десятых})$;",
        "(100, 999)": "<%spellout-cardinal-feminine-genitive< $(cardinal,one{сотой}other{сотых})$;",
        "(1000, 9999)": "<%spellout-cardinal-feminine-genitive< $(cardinal,one{тысячной}other{тысячных})$;",
        "(10000, 99999)": "<%spellout-cardinal-feminine-genitive< $(cardinal,one{десятитысячной}other{десятитысячных})$;",
        "(100000, 999999)": "<%spellout-cardinal-feminine-genitive< $(cardinal,one{стотысячной}other{стотысячных})$;",
        "(1000000, 9999999)": "<%spellout-cardinal-feminine-genitive< $(cardinal,one{миллионной}other{миллионных})$;",
        "(10000000, 99999999)": "<%spellout-cardinal-feminine-genitive< $(cardinal,one{десятимиллионной}other{десятимиллионных})$;",
        "(100000000, 999999999)": "<%spellout-cardinal-feminine-genitive< $(cardinal,one{стомиллионной}other{стомиллионных})$;",
        "(1000000000, 9999999999)": "<%spellout-cardinal-feminine-genitive< $(cardinal,one{миллиардной}other{миллиардных})$;",
        "(10000000000, 99999999999)": "<%spellout-cardinal-feminine-genitive< $(cardinal,one{десятимиллиардной}other{десятимиллиардных})$;",
        "(100000000000, 999999999999)": "<%spellout-cardinal-feminine-genitive< $(cardinal,one{стомиллиардной}other{стомиллиардных})$;",
        "(1000000000000, 'inf')": "<0<;"
    },
    "%%fractions-feminine-locative": {
        "(10, 99)": "<%spellout-cardinal-feminine-locative< $(cardinal,one{десятой}other{десятых})$;",
        "(100, 999)": "<%spellout-cardinal-feminine-locative< $(cardinal,one{сотой}other{сотых})$;",
        "(1000, 9999)": "<%spellout-cardinal-feminine-locative< $(cardinal,one{тысячной}other{тысячных})$;",
        "(10000, 99999)": "<%spellout-cardinal-feminine-locative< $(cardinal,one{десятитысячной}other{десятитысячных})$;",
        "(100000, 999999)": "<%spellout-cardinal-feminine-locative< $(cardinal,one{стотысячной}other{стотысячных})$;",
        "(1000000, 9999999)": "<%spellout-cardinal-feminine-locative< $(cardinal,one{миллионной}other{миллионных})$;",
        "(10000000, 99999999)": "<%spellout-cardinal-feminine-locative< $(cardinal,one{десятимиллионной}other{десятимиллионных})$;",
        "(100000000, 999999999)": "<%spellout-cardinal-feminine-locative< $(cardinal,one{стомиллионной}other{стомиллионных})$;",
        "(1000000000, 9999999999)": "<%spellout-cardinal-feminine-locative< $(cardinal,one{миллиардной}other{миллиардных})$;",
        "(10000000000, 99999999999)": "<%spellout-cardinal-feminine-locative< $(cardinal,one{десятимиллиардной}other{десятимиллиардных})$;",
        "(100000000000, 999999999999)": "<%spellout-cardinal-feminine-locative< $(cardinal,one{стомиллиардной}other{стомиллиардных})$;",
        "(1000000000000, 'inf')": "<0<;"
    },
    "%%oe": {
        "0": "ное;",
        "(1, 'inf')": "'а =%spellout-ordinal-neuter=;"
    },
    "%%ogo": {
        "0": "ного;",
        "(1, 'inf')": "'а =%spellout-ordinal-masculine-genitive=;"
    },
    "%%oj": {
        "0": "ной;",
        "(1, 'inf')": "'а =%spellout-ordinal-feminine-genitive=;"
    },
    "%%om": {
        "0": "ном;",
        "(1, 'inf')": "'а =%spellout-ordinal-masculine-locative=;"
    },
    "%%omu": {
        "0": "ному;",
        "(1, 'inf')": "'а =%spellout-ordinal-masculine-dative=;"
    },
    "%%thousandsprefixconjoined": {
        "0": "=%spellout-cardinal-feminine-genitive=;",
        "1": "одно;",
        "(2, 20)": "=%spellout-cardinal-feminine-genitive=;",
        "21": "двадцатиодно;",
        "(22, 29)": "двадцати[>>];",
        "30": "тридцати;",
        "31": "тридцатиодно;",
        "(32, 39)": "тридцати[>>];",
        "40": "сорока;",
        "41": "сорокаодно;",
        "(42, 49)": "сорока[>>];",
        "50": "пятидесяти;",
        "51": "пятидесятиодно;",
        "(52, 59)": "пятидесяти[>>];",
        "60": "шестидесяти;",
        "61": "шестидесятиодно;",
        "(62, 69)": "шестидесяти[>>];",
        "70": "семидесяти;",
        "71": "семидесятиодно;",
        "(72, 79)": "семидесяти[>>];",
        "80": "восьмидесяти;",
        "81": "восьмидесятиодно;",
        "(82, 89)": "восьмидесяти[>>];",
        "90": "=%spellout-cardinal-feminine=;",
        "91": "девяностоодно;",
        "(92, 99)": "девяносто[>>];",
        "(100, 199)": "сто[>>];",
        "(200, 'inf')": "<%spellout-cardinal-feminine-genitive<сот[>>];"
    },
    "%%thousandsprefixseparate": {
        "(0, 'inf')": "=%spellout-cardinal-feminine= ;"
    },
    "%%uju": {
        "0": "ную;",
        "(1, 'inf')": "'а =%spellout-ordinal-feminine-accusative=;"
    },
    "%%ye": {
        "0": "ные;",
        "(1, 'inf')": "'а =%spellout-ordinal-plural=;"
    },
    "%%yh": {
        "0": "ных;",
        "(1, 'inf')": "'а =%spellout-ordinal-plural-genitive=;"
    },
    "%%yj": {
        "0": "ный;",
        "(1, 'inf')": "'а =%spellout-ordinal-masculine=;"
    },
    "%%ym": {
        "0": "ным;",
        "(1, 'inf')": "'а =%spellout-ordinal-masculine-ablative=;"
    },
    "%%ymi": {
        "0": "ными;",
        "(1, 'inf')": "'а =%spellout-ordinal-plural-ablative=;"
    },
    "%spellout-cardinal-feminine": {
        "0": "ноль;",
        "1": "одна;",
        "2": "две;",
        "(3, 19)": "=%spellout-cardinal-masculine=;",
        "(20, 29)": "двадцать[ >>];",
        "(30, 39)": "тридцать[ >>];",
        "(40, 49)": "сорок[ >>];",
        "(50, 59)": "пятьдесят[ >>];",
        "(60, 69)": "шестьдесят[ >>];",
        "(70, 79)": "семьдесят[ >>];",
        "(80, 89)": "восемьдесят[ >>];",
        "(90, 99)": "девяносто[ >>];",
        "(100, 199)": "сто[ >>];",
        "(200, 299)": "<%spellout-cardinal-feminine<сти[ >>];",
        "(300, 499)": "<%spellout-cardinal-feminine<ста[ >>];",
        "(500, 999)": "<%spellout-cardinal-feminine<сот[ >>];",
        "(1000, 999999)": "<%spellout-cardinal-feminine< $(cardinal,one{тысяча}few{тысячи}other{тысяч})$[ >>];",
        "(1000000, 999999999)": "<%spellout-cardinal-masculine< $(cardinal,one{миллион}few{миллиона}other{миллионов})$[ >>];",
        "(1000000000, 999999999999)": "<%spellout-cardinal-masculine< $(cardinal,one{миллиард}few{миллиарда}other{миллиардов})$[ >>];",
        "(1000000000000, 999999999999999)": "<%spellout-cardinal-masculine< $(cardinal,one{триллион}few{триллиона}other{триллионов})$[ >>];",
        "(1000000000000000, 999999999999999999)": "<%spellout-cardinal-masculine< $(cardinal,one{квадриллион}few{квадриллиона}other{квадриллионов})$[ >>];",
        "(1000000000000000000, 'inf')": "=#,##0=;"
    },
    "%spellout-cardinal-feminine-ablative": {
        "0": "нулем;",
        "1": "одной;",
        "(2, 19)": "=%spellout-cardinal-masculine-ablative=;",
        "(20, 29)": "двадцатью[ >>];",
        "(30, 39)": "тридцатью[ >>];",
        "(40, 49)": "сорока[ >>];",
        "(50, 59)": "пятьюдесятью[ >>];",
        "(60, 69)": "шестьюдесятью[ >>];",
        "(70, 79)": "семьюдесятью[ >>];",
        "(80, 89)": "восемьюдесятью[ >>];",
        "(90, 99)": "девяноста[ >>];",
        "(100, 199)": "ста[ >>];",
        "(200, 999)": "<%spellout-cardinal-feminine-ablative<стами[ >>];",
        "(1000, 999999)": "<%spellout-cardinal-feminine-ablative< $(cardinal,one{тысячей}other{тысячами})$[ >>];",
        "(1000000, 999999999)": "<%spellout-cardinal-masculine-ablative< $(cardinal,one{миллионом}other{миллионами})$[ >>];",
        "(1000000000, 999999999999)": "<%spellout-cardinal-masculine-ablative< $(cardinal,one{миллиардом}other{миллиардами})$[ >>];",
        "(1000000000000, 999999999999999)": "<%spellout-cardinal-masculine-ablative< $(cardinal,one{триллионом}other{триллионами})$[ >>];",
        "(1000000000000000, 999999999999999999)": "<%spellout-cardinal-masculine-ablative< $(cardinal,one{квадриллионом}other{квадриллионами})$[ >>];",
        "(1000000000000000000, 'inf')": "=#,##0=;"
    },
    "%spellout-cardinal-feminine-accusative": {
        "0": "ноль;",
        "1": "одну;",
        "2": "две;",
        "(3, 19)": "=%spellout-cardinal-masculine-accusative=;",
        "(20, 29)": "двадцать[ >>];",
        "(30, 39)": "тридцать[ >>];",
        "(40, 49)": "сорок[ >>];",
        "(50, 59)": "пятьдесят[ >>];",
        "(60, 69)": "шестьдесят[ >>];",
        "(70, 79)": "семьдесят[ >>];",
        "(80, 89)": "восемьдесят[ >>];",
        "(90, 99)": "девяносто[ >>];",
        "(100, 199)": "сто[ >>];",
        "(200, 299)": "<%spellout-cardinal-feminine-accusative<сти[ >>];",
        "(300, 499)": "<%spellout-cardinal-feminine-accusative<ста[ >>];",
        "(500, 999)": "<%spellout-cardinal-feminine-accusative<сот[ >>];",
        "(1000, 999999)": "<%spellout-cardinal-feminine-accusative< $(cardinal,one{тысячу}few{тысячи}other{тысяч})$[ >>];",
        "(1000000, 999999999)": "<%spellout-cardinal-masculine-accusative< $(cardinal,one{миллион}few{миллиона}other{миллионов})$[ >>];",
        "(1000000000, 999999999999)": "<%spellout-cardinal-masculine-accusative< $(cardinal,one{миллиард}few{миллиарда}other{миллиардов})$[ >>];",
        "(1000000000000, 999999999999999)": "<%spellout-cardinal-masculine< $(cardinal,one{триллион}few{триллиона}other{триллионов})$[ >>];",
        "(1000000000000000, 999999999999999999)": "<%spellout-cardinal-masculine< $(cardinal,one{квадриллион}few{квадриллиона}other{квадриллионов})$[ >>];",
        "(1000000000000000000, 'inf')": "=#,##0=;"
    },
    "%spellout-cardinal-feminine-dative": {
        "0": "нолю;",
        "1": "одной;",
        "(2, 19)": "=%spellout-cardinal-masculine-dative=;",
        "(20, 29)": "двадцати[ >>];",
        "(30, 39)": "тридцати[ >>];",
        "(40, 49)": "сорока[ >>];",
        "(50, 59)": "пятидесяти[ >>];",
        "(60, 69)": "шестидесяти[ >>];",
        "(70, 79)": "семидесяти[ >>];",
        "(80, 89)": "восьмидесяти[ >>];",
        "(90, 99)": "девяноста[ >>];",
        "(100, 199)": "ста[ >>];",
        "(200, 999)": "<%spellout-cardinal-feminine-dative<стам[ >>];",
        "(1000, 999999)": "<%spellout-cardinal-feminine-dative< $(cardinal,one{тысяче}other{тысячам})$[ >>];",
        "(1000000, 999999999)": "<%spellout-cardinal-masculine-dative< $(cardinal,one{миллиону}other{миллионам})$[ >>];",
        "(1000000000, 999999999999)": "<%spellout-cardinal-masculine-dative< $(cardinal,one{миллиарду}other{миллиардам})$[ >>];",
        "(1000000000000, 999999999999999)": "<%spellout-cardinal-masculine-dative< $(cardinal,one{триллиону}other{триллионам})$[ >>];",
        "(1000000000000000, 999999999999999999)": "<%spellout-cardinal-masculine-dative< $(cardinal,one{квадриллиону}other{квадриллионам})$[ >>];",
        "(1000000000000000000, 'inf')": "=#,##0=;"
    },
    "%spellout-cardinal-feminine-genitive": {
        "0": "ноля;",
        "1": "одной;",
        "(2, 19)": "=%spellout-cardinal-masculine-genitive=;",
        "(20, 29)": "двадцати[ >>];",
        "(30, 39)": "тридцати[ >>];",
        "(40, 49)": "сорока[ >>];",
        "(50, 59)": "пятидесяти[ >>];",
        "(60, 69)": "шестидесяти[ >>];",
        "(70, 79)": "семидесяти[ >>];",
        "(80, 89)": "восьмидесяти[ >>];",
        "(90, 99)": "девяноста[ >>];",
        "(100, 199)": "ста[ >>];",
        "(200, 999)": "<%spellout-cardinal-feminine-genitive<сот[ >>];",
        "(1000, 999999)": "<%spellout-cardinal-feminine-genitive< $(cardinal,one{тысячи}other{тысяч})$[ >>];",
        "(1000000, 999999999)": "<%spellout-cardinal-masculine-genitive< $(cardinal,one{миллиона}other{миллионов})$[ >>];",
        "(1000000000, 999999999999)": "<%spellout-cardinal-masculine-genitive< $(cardinal,one{миллиарда}other{миллиардов})$[ >>];",
        "(1000000000000, 999999999999999)": "<%spellout-cardinal-masculine-genitive< $(cardinal,one{триллиона}other{триллионов})$[ >>];",
        "(1000000000000000, 999999999999999999)": "<%spellout-cardinal-masculine-genitive< $(cardinal,one{квадриллиона}other{квадриллионов})$[ >>];",
        "(1000000000000000000, 'inf')": "=#,##0=;"
    },
    "%spellout-cardinal-feminine-locative": {
        "0": "нуле;",
        "1": "одной;",
        "(2, 19)": "=%spellout-cardinal-masculine-locative=;",
        "(20, 29)": "двадцати[ >>];",
        "(30, 39)": "тридцати[ >>];",
        "(40, 49)": "сорока[ >>];",
        "(50, 59)": "пятидесяти[ >>];",
        "(60, 69)": "шестидесяти[ >>];",
        "(70, 79)": "семидесяти[ >>];",
        "(80, 89)": "восьмидесяти[ >>];",
        "(90, 99)": "девяноста[ >>];",
        "(100, 199)": "ста[ >>];",
        "(200, 999)": "<%spellout-cardinal-feminine-locative<стах[ >>];",
        "(1000, 999999)": "<%spellout-cardinal-feminine-locative< $(cardinal,one{тысяче}other{тысячах})$[ >>];",
        "(1000000, 999999999)": "<%spellout-cardinal-masculine-locative< $(cardinal,one{миллионе}other{миллионах})$[ >>];",
        "(1000000000, 999999999999)": "<%spellout-cardinal-masculine-locative< $(cardinal,one{миллиарде}other{миллиардах})$[ >>];",
        "(1000000000000, 999999999999999)": "<%spellout-cardinal-masculine-locative< $(cardinal,one{триллионе}other{триллионах})$[ >>];",
        "(1000000000000000, 999999999999999999)": "<%spellout-cardinal-masculine-locative< $(cardinal,one{квадриллионе}other{квадриллионах})$[ >>];",
        "(1000000000000000000, 'inf')": "=#,##0=;"
    },
    "%spellout-cardinal-masculine": {
        "0": "ноль;",
        "1": "один;",
        "2": "два;",
        "3": "три;",
        "4": "четыре;",
        "5": "пять;",
        "6": "шесть;",
        "7": "семь;",
        "8": "восемь;",
        "9": "девять;",
        "10": "десять;",
        "11": "одиннадцать;",
        "12": "двенадцать;",
        "13": "тринадцать;",
        "14": "четырнадцать;",
        "15": "пятнадцать;",
        "16": "шестнадцать;",
        "17": "семнадцать;",
        "18": "восемнадцать;",
        "19": "девятнадцать;",
        "(20, 29)": "двадцать[ >>];",
        "(30, 39)": "тридцать[ >>];",
        "(40, 49)": "сорок[ >>];",
        "(50, 59)": "пятьдесят[ >>];",
        "(60, 69)": "шестьдесят[ >>];",
        "(70, 79)": "семьдесят[ >>];",
        "(80, 89)": "восемьдесят[ >>];",
        "(90, 99)": "девяносто[ >>];",
        "(100, 199)": "сто[ >>];",
        "(200, 299)": "<%spellout-cardinal-feminine<сти[ >>];",
        "(300, 499)": "<%spellout-cardinal-feminine<ста[ >>];",
        "(500, 999)": "<%spellout-cardinal-feminine<сот[ >>];",
        "(1000, 999999)": "<%spellout-cardinal-feminine< $(cardinal,one{тысяча}few{тысячи}other{тысяч})$[ >>];",
        "(1000000, 999999999)": "<%spellout-cardinal-masculine< $(cardinal,one{миллион}few{миллиона}other{миллионов})$[ >>];",
        "(1000000000, 999999999999)": "<%spellout-cardinal-masculine< $(cardinal,one{миллиард}few{миллиарда}other{миллиардов})$[ >>];",
        "(1000000000000, 999999999999999)": "<%spellout-cardinal-masculine< $(cardinal,one{триллион}few{триллиона}other{триллионов})$[ >>];",
        "(1000000000000000, 999999999999999999)": "<%spellout-cardinal-masculine< $(cardinal,one{квадриллион}few{квадриллиона}other{квадриллионов})$[ >>];",
        "(1000000000000000000, 'inf')": "=#,##0=;"
    },
    "%spellout-cardinal-masculine-ablative": {
        "0": "нулем;",
        "1": "одним;",
        "2": "двумя;",
        "3": "тремя;",
        "4": "четырьмя;",
        "5": "пятью;",
        "6": "шестью;",
        "7": "семью;",
        "8": "восемью;",
        "9": "девятью;",
        "10": "десятью;",
        "11": "одиннадцатью;",
        "12": "двенадцатью;",
        "13": "тринадцатью;",
        "14": "четырнадцатью;",
        "15": "пятнадцатью;",
        "16": "шестнадцатью;",
        "17": "семнадцатью;",
        "18": "восемнадцатью;",
        "19": "девятнадцатью;",
        "(20, 29)": "двадцатью[ >>];",
        "(30, 39)": "тридцатью[ >>];",
        "(40, 49)": "сорока[ >>];",
        "(50, 59)": "пятьюдесятью[ >>];",
        "(60, 69)": "шестьюдесятью[ >>];",
        "(70, 79)": "семьюдесятью[ >>];",
        "(80, 89)": "восемьюдесятью[ >>];",
        "(90, 99)": "девяноста[ >>];",
        "(100, 199)": "ста[ >>];",
        "(200, 999)": "<%spellout-cardinal-feminine-ablative<стами[ >>];",
        "(1000, 999999)": "<%spellout-cardinal-feminine-ablative< $(cardinal,one{тысячей}other{тысячами})$[ >>];",
        "(1000000, 999999999)": "<%spellout-cardinal-masculine-ablative< $(cardinal,one{миллионом}other{миллионами})$[ >>];",
        "(1000000000, 999999999999)": "<%spellout-cardinal-masculine-ablative< $(cardinal,one{миллиардом}other{миллиардами})$[ >>];",
        "(1000000000000, 999999999999999)": "<%spellout-cardinal-masculine-ablative< $(cardinal,one{триллионом}other{триллионами})$[ >>];",
        "(1000000000000000, 999999999999999999)": "<%spellout-cardinal-masculine-ablative< $(cardinal,one{квадриллионом}other{квадриллионами})$[ >>];",
        "(1000000000000000000, 'inf')": "=#,##0=;"
    },
    "%spellout-cardinal-masculine-accusative": {
        "0": "ноль;",
        "1": "один;",
        "2": "два;",
        "3": "три;",
        "4": "четыре;",
        "5": "пять;",
        "6": "шесть;",
        "7": "семь;",
        "8": "восемь;",
        "9": "девять;",
        "10": "десять;",
        "11": "одиннадцать;",
        "12": "двенадцать;",
        "13": "тринадцать;",
        "14": "четырнадцать;",
        "15": "пятнадцать;",
        "16": "шестнадцать;",
        "17": "семнадцать;",
        "18": "восемнадцать;",
        "19": "девятнадцать;",
        "(20, 29)": "двадцать[ >>];",
        "(30, 39)": "тридцать[ >>];",
        "(40, 49)": "сорок[ >>];",
        "(50, 59)": "пятьдесят[ >>];",
        "(60, 69)": "шестьдесят[ >>];",
        "(70, 79)": "семьдесят[ >>];",
        "(80, 89)": "восемьдесят[ >>];",
        "(90, 99)": "девяносто[ >>];",
        "(100, 199)": "сто[ >>];",
        "(200, 299)": "<%spellout-cardinal-feminine-accusative<сти[ >>];",
        "(300, 499)": "<%spellout-cardinal-feminine-accusative<ста[ >>];",
        "(500, 999)": "<%spellout-cardinal-feminine-accusative<сот[ >>];",
        "(1000, 999999)": "<%spellout-cardinal-feminine-accusative< $(cardinal,one{тысячу}few{тысячи}other{тысяч})$[ >>];",
        "(1000000, 999999999)": "<%spellout-cardinal-masculine-accusative< $(cardinal,one{миллион}few{миллиона}other{миллионов})$[ >>];",
        "(1000000000, 999999999999)": "<%spellout-cardinal-masculine-accusative< $(cardinal,one{миллиард}few{миллиарда}other{миллиардов})$[ >>];",
        "(1000000000000, 999999999999999)": "<%spellout-cardinal-masculine< $(cardinal,one{триллион}few{триллиона}other{триллионов})$[ >>];",
        "(1000000000000000, 999999999999999999)": "<%spellout-cardinal-masculine< $(cardinal,one{квадриллион}few{квадриллиона}other{квадриллионов})$[ >>];",
        "(1000000000000000000, 'inf')": "=#,##0=;"
    },
    "%spellout-cardinal-masculine-dative": {
        "0": "нолю;",
        "1": "одному;",
        "2": "двум;",
        "3": "трем;",
        "4": "четырем;",
        "5": "пяти;",
        "6": "шести;",
        "7": "семи;",
        "8": "восьми;",
        "9": "девяти;",
        "10": "десяти;",
        "11": "одиннадцати;",
        "12": "двенадцати;",
        "13": "тринадцати;",
        "14": "четырнадцати;",
        "15": "пятнадцати;",
        "16": "шестнадцати;",
        "17": "семнадцати;",
        "18": "восемнадцати;",
        "19": "девятнадцати;",
        "(20, 29)": "двадцати[ >>];",
        "(30, 39)": "тридцати[ >>];",
        "(40, 49)": "сорока[ >>];",
        "(50, 59)": "пятидесяти[ >>];",
        "(60, 69)": "шестидесяти[ >>];",
        "(70, 79)": "семидесяти[ >>];",
        "(80, 89)": "восьмидесяти[ >>];",
        "(90, 99)": "девяноста[ >>];",
        "(100, 199)": "ста[ >>];",
        "(200, 999)": "<%spellout-cardinal-feminine-dative<стам[ >>];",
        "(1000, 999999)": "<%spellout-cardinal-feminine-dative< $(cardinal,one{тысяче}other{тысячам})$[ >>];",
        "(1000000, 999999999)": "<%spellout-cardinal-masculine-dative< $(cardinal,one{миллиону}other{миллионам})$[ >>];",
        "(1000000000, 999999999999)": "<%spellout-cardinal-masculine-dative< $(cardinal,one{миллиарду}other{миллиардам})$[ >>];",
        "(1000000000000, 999999999999999)": "<%spellout-cardinal-masculine-dative< $(cardinal,one{триллиону}other{триллионам})$[ >>];",
        "(1000000000000000, 999999999999999999)": "<%spellout-cardinal-masculine-dative< $(cardinal,one{квадриллиону}other{квадриллионам})$[ >>];",
        "(1000000000000000000, 'inf')": "=#,##0=;"
    },
    "%spellout-cardinal-masculine-genitive": {
        "0": "ноля;",
        "1": "одного;",
        "2": "двух;",
        "3": "трех;",
        "4": "четырех;",
        "5": "пяти;",
        "6": "шести;",
        "7": "семи;",
        "8": "восьми;",
        "9": "девяти;",
        "10": "десяти;",
        "11": "одиннадцати;",
        "12": "двенадцати;",
        "13": "тринадцати;",
        "14": "четырнадцати;",
        "15": "пятнадцати;",
        "16": "шестнадцати;",
        "17": "семнадцати;",
        "18": "восемнадцати;",
        "19": "девятнадцати;",
        "(20, 29)": "двадцати[ >>];",
        "(30, 39)": "тридцати[ >>];",
        "(40, 49)": "сорока[ >>];",
        "(50, 59)": "пятидесяти[ >>];",
        "(60, 69)": "шестидесяти[ >>];",
        "(70, 79)": "семидесяти[ >>];",
        "(80, 89)": "восьмидесяти[ >>];",
        "(90, 99)": "девяноста[ >>];",
        "(100, 199)": "ста[ >>];",
        "(200, 999)": "<%spellout-cardinal-feminine-genitive<сот[ >>];",
        "(1000, 999999)": "<%spellout-cardinal-feminine-genitive< $(cardinal,one{тысячи}other{тысяч})$[ >>];",
        "(1000000, 999999999)": "<%spellout-cardinal-masculine-genitive< $(cardinal,one{миллиона}other{миллионов})$[ >>];",
        "(1000000000, 999999999999)": "<%spellout-cardinal-masculine-genitive< $(cardinal,one{миллиарда}other{миллиардов})$[ >>];",
        "(1000000000000, 999999999999999)": "<%spellout-cardinal-masculine-genitive< $(cardinal,one{триллиона}other{триллионов})$[ >>];",
        "(1000000000000000, 999999999999999999)": "<%spellout-cardinal-masculine-genitive< $(cardinal,one{квадриллиона}other{квадриллионов})$[ >>];",
        "(1000000000000000000, 'inf')": "=#,##0=;"
    },
    "%spellout-cardinal-masculine-locative": {
        "0": "нуле;",
        "1": "одном;",
        "2": "двух;",
        "3": "трех;",
        "4": "четырех;",
        "5": "пяти;",
        "6": "шести;",
        "7": "семи;",
        "8": "восьми;",
        "9": "девяти;",
        "10": "десяти;",
        "11": "одиннадцати;",
        "12": "двенадцати;",
        "13": "тринадцати;",
        "14": "четырнадцати;",
        "15": "пятнадцати;",
        "16": "шестнадцати;",
        "17": "семнадцати;",
        "18": "восемнадцати;",
        "19": "девятнадцати;",
        "(20, 29)": "двадцать[ >>];",
        "(30, 39)": "тридцать[ >>];",
        "(40, 49)": "сорока[ >>];",
        "(50, 59)": "пятидесяти[ >>];",
        "(60, 69)": "шестидесяти[ >>];",
        "(70, 79)": "семидесяти[ >>];",
        "(80, 89)": "восьмидесяти[ >>];",
        "(90, 99)": "девяноста[ >>];",
        "(100, 199)": "ста[ >>];",
        "(200, 999)": "<%spellout-cardinal-feminine-locative<стах[ >>];",
        "(1000, 999999)": "<%spellout-cardinal-feminine-locative< $(cardinal,one{тысяче}other{тысячах})$[ >>];",
        "(1000000, 999999999)": "<%spellout-cardinal-masculine-locative< $(cardinal,one{миллионе}other{миллионах})$[ >>];",
        "(1000000000, 999999999999)": "<%spellout-cardinal-masculine-locative< $(cardinal,one{миллиарде}other{миллиардах})$[ >>];",
        "(1000000000000, 999999999999999)": "<%spellout-cardinal-masculine-locative< $(cardinal,one{триллионе}other{триллионах})$[ >>];",
        "(1000000000000000, 999999999999999999)": "<%spellout-cardinal-masculine-locative< $(cardinal,one{квадриллионе}other{квадриллионах})$[ >>];",
        "(1000000000000000000, 'inf')": "=#,##0=;"
    },
    "%spellout-cardinal-neuter": {
        "0": "ноль;",
        "1": "одно;",
        "(2, 19)": "=%spellout-cardinal-masculine=;",
        "(20, 29)": "двадцать[ >>];",
        "(30, 39)": "тридцать[ >>];",
        "(40, 49)": "сорок[ >>];",
        "(50, 59)": "пятьдесят[ >>];",
        "(60, 69)": "шестьдесят[ >>];",
        "(70, 79)": "семьдесят[ >>];",
        "(80, 89)": "восемьдесят[ >>];",
        "(90, 99)": "девяносто[ >>];",
        "(100, 199)": "сто[ >>];",
        "(200, 299)": "<%spellout-cardinal-feminine<сти[ >>];",
        "(300, 499)": "<%spellout-cardinal-feminine<ста[ >>];",
        "(500, 999)": "<%spellout-cardinal-feminine<сот[ >>];",
        "(1000, 999999)": "<%spellout-cardinal-feminine< $(cardinal,one{тысяча}few{тысячи}other{тысяч})$[ >>];",
        "(1000000, 999999999)": "<%spellout-cardinal-masculine< $(cardinal,one{миллион}few{миллиона}other{миллионов})$[ >>];",
        "(1000000000, 999999999999)": "<%spellout-cardinal-masculine< $(cardinal,one{миллиард}few{миллиарда}other{миллиардов})$[ >>];",
        "(1000000000000, 999999999999999)": "<%spellout-cardinal-masculine< $(cardinal,one{триллион}few{триллиона}other{триллионов})$[ >>];",
        "(1000000000000000, 999999999999999999)": "<%spellout-cardinal-masculine< $(cardinal,one{квадриллион}few{квадриллиона}other{квадриллионов})$[ >>];",
        "(1000000000000000000, 'inf')": "=#,##0=;"
    },
    "%spellout-cardinal-neuter-ablative": {
        "(0, 'inf')": "=%spellout-cardinal-masculine-ablative=;"
    },
    "%spellout-cardinal-neuter-accusative": {
        "0": "ноль;",
        "1": "одно;",
        "(2, 19)": "=%spellout-cardinal-masculine-accusative=;",
        "(20, 29)": "двадцать[ >>];",
        "(30, 39)": "тридцать[ >>];",
        "(40, 49)": "сорок[ >>];",
        "(50, 59)": "пятьдесят[ >>];",
        "(60, 69)": "шестьдесят[ >>];",
        "(70, 79)": "семьдесят[ >>];",
        "(80, 89)": "восемьдесят[ >>];",
        "(90, 99)": "девяносто[ >>];",
        "(100, 199)": "сто[ >>];",
        "(200, 299)": "<%spellout-cardinal-feminine-accusative<сти[ >>];",
        "(300, 499)": "<%spellout-cardinal-feminine-accusative<ста[ >>];",
        "(500, 999)": "<%spellout-cardinal-feminine-accusative<сот[ >>];",
        "(1000, 999999)": "<%spellout-cardinal-feminine-accusative< $(cardinal,one{тысячу}few{тысячи}other{тысяч})$[ >>];",
        "(1000000, 999999999)": "<%spellout-cardinal-masculine-accusative< $(cardinal,one{миллион}few{миллиона}other{миллионов})$[ >>];",
        "(1000000000, 999999999999)": "<%spellout-cardinal-masculine-accusative< $(cardinal,one{миллиард}few{миллиарда}other{миллиардов})$[ >>];",
        "(1000000000000, 999999999999999)": "<%spellout-cardinal-masculine< $(cardinal,one{триллион}few{триллиона}other{триллионов})$[ >>];",
        "(1000000000000000, 999999999999999999)": "<%spellout-cardinal-masculine< $(cardinal,one{квадриллион}few{квадриллиона}other{квадриллионов})$[ >>];",
        "(1000000000000000000, 'inf')": "=#,##0=;"
    },
    "%spellout-cardinal-neuter-dative": {
        "(0, 'inf')": "=%spellout-cardinal-masculine-dative=;"
    },
    "%spellout-cardinal-neuter-genitive": {
        "(0, 'inf')": "=%spellout-cardinal-masculine-genitive=;"
    },
    "%spellout-cardinal-neuter-locative": {
        "0": "нуле;",
        "1": "одном;",
        "(2, 19)": "=%spellout-cardinal-masculine-locative=;",
        "(20, 29)": "двадцати[ >>];",
        "(30, 39)": "тридцати[ >>];",
        "(40, 49)": "сорока[ >>];",
        "(50, 59)": "пятидесяти[ >>];",
        "(60, 69)": "шестидесяти[ >>];",
        "(70, 79)": "семидесяти[ >>];",
        "(80, 89)": "восьмидесяти[ >>];",
        "(90, 99)": "девяноста[ >>];",
        "(100, 199)": "ста[ >>];",
        "(200, 999)": "<%spellout-cardinal-feminine-locative<стах[ >>];",
        "(1000, 999999)": "<%spellout-cardinal-feminine-locative< $(cardinal,one{тысяче}other{тысячах})$[ >>];",
        "(1000000, 999999999)": "<%spellout-cardinal-masculine-locative< $(cardinal,one{миллионе}other{миллионах})$[ >>];",
        "(1000000000, 999999999999)": "<%spellout-cardinal-masculine-locative< $(cardinal,one{миллиарде}other{миллиардах})$[ >>];",
        "(1000000000000, 999999999999999)": "<%spellout-cardinal-masculine-locative< $(cardinal,one{триллионе}other{триллионах})$[ >>];",
        "(1000000000000000, 999999999999999999)": "<%spellout-cardinal-masculine-locative< $(cardinal,one{квадриллионе}other{квадриллионах})$[ >>];",
        "(1000000000000000000, 'inf')": "=#,##0=;"
    },
    "%spellout-cardinal-plural": {
        "0": "ноль;",
        "1": "одни;",
        "2": "две;",
        "(3, 19)": "=%spellout-cardinal-masculine=;",
        "(20, 29)": "двадцать[ >>];",
        "(30, 39)": "тридцать[ >>];",
        "(40, 49)": "сорок[ >>];",
        "(50, 59)": "пятьдесят[ >>];",
        "(60, 69)": "шестьдесят[ >>];",
        "(70, 79)": "семьдесят[ >>];",
        "(80, 89)": "восемьдесят[ >>];",
        "(90, 99)": "девяносто[ >>];",
        "(100, 199)": "сто[ >>];",
        "(200, 299)": "<%spellout-cardinal-feminine<сти[ >>];",
        "(300, 499)": "<%spellout-cardinal-feminine<ста[ >>];",
        "(500, 999)": "<%spellout-cardinal-feminine<сот[ >>];",
        "(1000, 999999)": "<%spellout-cardinal-feminine< $(cardinal,one{тысяча}few{тысячи}other{тысяч})$[ >>];",
        "(1000000, 999999999)": "<%spellout-cardinal-masculine< $(cardinal,one{миллион}few{миллиона}other{миллионов})$[ >>];",
        "(1000000000, 999999999999)": "<%spellout-cardinal-masculine< $(cardinal,one{миллиард}few{миллиарда}other{миллиардов})$[ >>];",
        "(1000000000000, 999999999999999)": "<%spellout-cardinal-masculine< $(cardinal,one{триллион}few{триллиона}other{триллионов})$[ >>];",
        "(1000000000000000, 999999999999999999)": "<%spellout-cardinal-masculine< $(cardinal,one{квадриллион}few{квадриллиона}other{квадриллионов})$[ >>];",
        "(1000000000000000000, 'inf')": "=#,##0=;"
    },
    "%spellout-cardinal-plural-ablative": {
        "0": "нулем;",
        "1": "одними;",
        "(2, 19)": "=%spellout-cardinal-masculine-ablative=;",
        "(20, 29)": "двадцатью[ >>];",
        "(30, 39)": "тридцатью[ >>];",
        "(40, 49)": "сорока[ >>];",
        "(50, 59)": "пятьюдесятью[ >>];",
        "(60, 69)": "шестьюдесятью[ >>];",
        "(70, 79)": "семьюдесятью[ >>];",
        "(80, 89)": "восемьюдесятью[ >>];",
        "(90, 99)": "девяноста[ >>];",
        "(100, 199)": "ста[ >>];",
        "(200, 999)": "<%spellout-cardinal-feminine-ablative<стами[ >>];",
        "(1000, 999999)": "<%spellout-cardinal-feminine-ablative< $(cardinal,one{тысячей}other{тысячами})$[ >>];",
        "(1000000, 999999999)": "<%spellout-cardinal-masculine-ablative< $(cardinal,one{миллионом}other{миллионами})$[ >>];",
        "(1000000000, 999999999999)": "<%spellout-cardinal-masculine-ablative< $(cardinal,one{миллиардом}other{миллиардами})$[ >>];",
        "(1000000000000, 999999999999999)": "<%spellout-cardinal-masculine-ablative< $(cardinal,one{триллионом}other{триллионами})$[ >>];",
        "(1000000000000000, 999999999999999999)": "<%spellout-cardinal-masculine-ablative< $(cardinal,one{квадриллионом}other{квадриллионами})$[ >>];",
        "(1000000000000000000, 'inf')": "=#,##0=;"
    },
    "%spellout-cardinal-plural-accusative": {
        "0": "ноль;",
        "1": "одни;",
        "2": "две;",
        "(3, 19)": "=%spellout-cardinal-masculine-accusative=;",
        "(20, 29)": "двадцать[ >>];",
        "(30, 39)": "тридцать[ >>];",
        "(40, 49)": "сорок[ >>];",
        "(50, 59)": "пятьдесят[ >>];",
        "(60, 69)": "шестьдесят[ >>];",
        "(70, 79)": "семьдесят[ >>];",
        "(80, 89)": "восемьдесят[ >>];",
        "(90, 99)": "девяносто[ >>];",
        "(100, 199)": "сто[ >>];",
        "(200, 299)": "<%spellout-cardinal-feminine-accusative<сти[ >>];",
        "(300, 499)": "<%spellout-cardinal-feminine-accusative<ста[ >>];",
        "(500, 999)": "<%spellout-cardinal-feminine-accusative<сот[ >>];",
        "(1000, 999999)": "<%spellout-cardinal-feminine-accusative< $(cardinal,one{тысячу}few{тысячи}other{тысяч})$[ >>];",
        "(1000000, 999999999)": "<%spellout-cardinal-masculine-accusative< $(cardinal,one{миллион}few{миллиона}other{миллионов})$[ >>];",
        "(1000000000, 999999999999)": "<%spellout-cardinal-masculine-accusative< $(cardinal,one{миллиард}few{миллиарда}other{миллиардов})$[ >>];",
        "(1000000000000, 999999999999999)": "<%spellout-cardinal-masculine< $(cardinal,one{триллион}few{триллиона}other{триллионов})$[ >>];",
        "(1000000000000000, 999999999999999999)": "<%spellout-cardinal-masculine< $(cardinal,one{квадриллион}few{квадриллиона}other{квадриллионов})$[ >>];",
        "(1000000000000000000, 'inf')": "=#,##0=;"
    },
    "%spellout-cardinal-plural-dative": {
        "0": "нолю;",
        "1": "одним;",
        "(2, 19)": "=%spellout-cardinal-masculine-dative=;",
        "(20, 29)": "двадцати[ >>];",
        "(30, 39)": "тридцати[ >>];",
        "(40, 49)": "сорока[ >>];",
        "(50, 59)": "пятидесяти[ >>];",
        "(60, 69)": "шестидесяти[ >>];",
        "(70, 79)": "семидесяти[ >>];",
        "(80, 89)": "восьмидесяти[ >>];",
        "(90, 99)": "девяноста[ >>];",
        "(100, 199)": "ста[ >>];",
        "(200, 999)": "<%spellout-cardinal-feminine-dative<стам[ >>];",
        "(1000, 999999)": "<%spellout-cardinal-feminine-dative< $(cardinal,one{тысяче}other{тысячам})$[ >>];",
        "(1000000, 999999999)": "<%spellout-cardinal-masculine-dative< $(cardinal,one{миллиону}other{миллионам})$[ >>];",
        "(1000000000, 999999999999)": "<%spellout-cardinal-masculine-dative< $(cardinal,one{миллиарду}other{миллиардам})$[ >>];",
        "(1000000000000, 999999999999999)": "<%spellout-cardinal-masculine-dative< $(cardinal,one{триллиону}other{триллионам})$[ >>];",
        "(1000000000000000, 999999999999999999)": "<%spellout-cardinal-masculine-dative< $(cardinal,one{квадриллиону}other{квадриллионам})$[ >>];",
        "(1000000000000000000, 'inf')": "=#,##0=;"
    },
    "%spellout-cardinal-plural-genitive": {
        "0": "ноля;",
        "1": "одних;",
        "(2, 19)": "=%spellout-cardinal-masculine-genitive=;",
        "(20, 29)": "двадцати[ >>];",
        "(30, 39)": "тридцати[ >>];",
        "(40, 49)": "сорока[ >>];",
        "(50, 59)": "пятидесяти[ >>];",
        "(60, 69)": "шестидесяти[ >>];",
        "(70, 79)": "семидесяти[ >>];",
        "(80, 89)": "восьмидесяти[ >>];",
        "(90, 99)": "девяноста[ >>];",
        "(100, 199)": "ста[ >>];",
        "(200, 999)": "<%spellout-cardinal-feminine-genitive<сот[ >>];",
        "(1000, 999999)": "<%spellout-cardinal-feminine-genitive< $(cardinal,one{тысячи}other{тысяч})$[ >>];",
        "(1000000, 999999999)": "<%spellout-cardinal-masculine-genitive< $(cardinal,one{миллиона}other{миллионов})$[ >>];",
        "(1000000000, 999999999999)": "<%spellout-cardinal-masculine-genitive< $(cardinal,one{миллиарда}other{миллиардов})$[ >>];",
        "(1000000000000, 999999999999999)": "<%spellout-cardinal-masculine-genitive< $(cardinal,one{триллиона}other{триллионов})$[ >>];",
        "(1000000000000000, 999999999999999999)": "<%spellout-cardinal-masculine-genitive< $(cardinal,one{квадриллиона}other{квадриллионов})$[ >>];",
        "(1000000000000000000, 'inf')": "=#,##0=;"
    },
    "%spellout-cardinal-plural-locative": {
        "0": "нуле;",
        "1": "одних;",
        "(2, 19)": "=%spellout-cardinal-masculine-locative=;",
        "(20, 29)": "двадцати[ >>];",
        "(30, 39)": "тридцати[ >>];",
        "(40, 49)": "сорока[ >>];",
        "(50, 59)": "пятидесяти[ >>];",
        "(60, 69)": "шестидесяти[ >>];",
        "(70, 79)": "семидесяти[ >>];",
        "(80, 89)": "восьмидесяти[ >>];",
        "(90, 99)": "девяноста[ >>];",
        "(100, 199)": "ста[ >>];",
        "(200, 999)": "<%spellout-cardinal-feminine-locative<стах[ >>];",
        "(1000, 999999)": "<%spellout-cardinal-feminine-locative< $(cardinal,one{тысяче}other{тысячах})$[ >>];",
        "(1000000, 999999999)": "<%spellout-cardinal-masculine-locative< $(cardinal,one{миллионе}other{миллионах})$[ >>];",
        "(1000000000, 999999999999)": "<%spellout-cardinal-masculine-locative< $(cardinal,one{миллиарде}other{миллиардах})$[ >>];",
        "(1000000000000, 999999999999999)": "<%spellout-cardinal-masculine-locative< $(cardinal,one{триллионе}other{триллионах})$[ >>];",
        "(1000000000000000, 999999999999999999)": "<%spellout-cardinal-masculine-locative< $(cardinal,one{квадриллионе}other{квадриллионах})$[ >>];",
        "(1000000000000000000, 'inf')": "=#,##0=;"
    },
    "%spellout-numbering": {
        "(0, 'inf')": "=%spellout-cardinal-masculine=;"
    },
    "%spellout-numbering-year": {
        "(0, 'inf')": "=%spellout-ordinal-masculine-genitive=;"
    },
    "%spellout-ordinal-feminine": {
        "0": "ноль;",
        "1": "первая;",
        "2": "вторая;",
        "3": "третья;",
        "4": "четвертая;",
        "5": "пятая;",
        "6": "шестая;",
        "7": "седьмая;",
        "8": "восьмая;",
        "9": "девятая;",
        "10": "десятая;",
        "11": "одиннадцатая;",
        "12": "двенадцатая;",
        "13": "тринадцатая;",
        "14": "четырнадцатая;",
        "15": "пятнадцатая;",
        "16": "шестнадцатая;",
        "17": "семнадцатая;",
        "18": "восемнадцатая;",
        "19": "девятнадцатая;",
        "20": "двадцатая;",
        "(21, 29)": "двадцать >>;",
        "30": "тридцатая;",
        "(31, 39)": "тридцать >>;",
        "40": "сороковая;",
        "(41, 49)": "сорок >>;",
        "50": "пятидесятая;",
        "(51, 59)": "пятьдесят >>;",
        "60": "шестидесятая;",
        "(61, 69)": "шестьдесят >>;",
        "70": "семидесятая;",
        "(71, 79)": "семьдесят >>;",
        "80": "восьмидесятая;",
        "(81, 89)": "восемьдесят >>;",
        "90": "девяностая;",
        "(91, 99)": "девяносто >>;",
        "100": "сотая;",
        "(101, 199)": "сто >>;",
        "(200, 299)": "<%spellout-cardinal-feminine<сти[ >>];",
        "(300, 499)": "<%spellout-cardinal-feminine<ста[ >>];",
        "(500, 999)": "<%spellout-cardinal-feminine<сот[ >>];",
        "1000": "тысяч>%%aja>;",
        "(1001, 21000)": "одна тысяч>%%aja>;",
        "(21001, 'inf')": "=0=.;"
    },
    "%spellout-ordinal-feminine-ablative": {
        "(0, 'inf')": "=%spellout-ordinal-feminine-genitive=;"
    },
    "%spellout-ordinal-feminine-accusative": {
        "0": "нулевую;",
        "1": "первую;",
        "2": "вторую;",
        "3": "третью;",
        "4": "четвертую;",
        "5": "пятую;",
        "6": "шестую;",
        "7": "седьмую;",
        "8": "восьмую;",
        "9": "девятую;",
        "10": "десятую;",
        "11": "одиннадцатую;",
        "12": "двенадцатую;",
        "13": "тринадцатую;",
        "14": "четырнадцатую;",
        "15": "пятнадцатую;",
        "16": "шестнадцатую;",
        "17": "семнадцатую;",
        "18": "восемнадцатую;",
        "19": "девятнадцатую;",
        "20": "двадцатую;",
        "(21, 29)": "двадцать >>;",
        "30": "тридцатую;",
        "(31, 39)": "тридцать >>;",
        "40": "сороковую;",
        "(41, 49)": "сорок >>;",
        "50": "пятидесятую;",
        "(51, 59)": "пятьдесят >>;",
        "60": "шестидесятую;",
        "(61, 69)": "шестьдесят >>;",
        "70": "семидесятую;",
        "(71, 79)": "семьдесят >>;",
        "80": "восьмидесятую;",
        "(81, 89)": "восемьдесят >>;",
        "90": "девяностую;",
        "(91, 99)": "девяносто >>;",
        "100": "сотую;",
        "(101, 199)": "сто >>;",
        "(200, 299)": "<%spellout-cardinal-feminine<сти[ >>];",
        "(300, 499)": "<%spellout-cardinal-feminine<ста[ >>];",
        "(500, 999)": "<%spellout-cardinal-feminine<сот[ >>];",
        "1000": "тысяч>%%uju>;",
        "(1001, 21000)": "одна тысяч>%%uju>;",
        "(21001, 'inf')": "=0=.;"
    },
    "%spellout-ordinal-feminine-dative": {
        "(0, 'inf')": "=%spellout-ordinal-feminine-genitive=;"
    },
    "%spellout-ordinal-feminine-genitive": {
        "0": "нулевой;",
        "1": "первой;",
        "2": "второй;",
        "3": "третьей;",
        "4": "четвертой;",
        "5": "пятой;",
        "6": "шестой;",
        "7": "седьмой;",
        "8": "восьмой;",
        "9": "девятой;",
        "10": "десятой;",
        "11": "одиннадцатой;",
        "12": "двенадцатой;",
        "13": "тринадцатой;",
        "14": "четырнадцатой;",
        "15": "пятнадцатой;",
        "16": "шестнадцатой;",
        "17": "семнадцатой;",
        "18": "восемнадцатой;",
        "19": "девятнадцатой;",
        "20": "двадцатой;",
        "(21, 29)": "двадцать >>;",
        "30": "тридцатой;",
        "(31, 39)": "тридцать >>;",
        "40": "сороковой;",
        "(41, 49)": "сорок >>;",
        "50": "пятидесятой;",
        "(51, 59)": "пятьдесят >>;",
        "60": "шестидесятой;",
        "(61, 69)": "шестьдесят >>;",
        "70": "семидесятой;",
        "(71, 79)": "семьдесят >>;",
        "80": "восьмидесятой;",
        "(81, 89)": "восемьдесят >>;",
        "90": "девяностой;",
        "(91, 99)": "девяносто >>;",
        "100": "сотой;",
        "(101, 199)": "сто >>;",
        "(200, 299)": "<%spellout-cardinal-feminine<сти[ >>];",
        "(300, 499)": "<%spellout-cardinal-feminine<ста[ >>];",
        "(500, 999)": "<%spellout-cardinal-feminine<сот[ >>];",
        "1000": "тысяч>%%oj>;",
        "(1001, 21000)": "одна тысяч>%%oj>;",
        "(21001, 'inf')": "=0=.;"
    },
    "%spellout-ordinal-feminine-locative": {
        "(0, 'inf')": "=%spellout-ordinal-feminine-genitive=;"
    },
    "%spellout-ordinal-masculine": {
        "0": "нулевой;",
        "1": "первый;",
        "2": "второй;",
        "3": "третий;",
        "4": "четвертый;",
        "5": "пятый;",
        "6": "шестой;",
        "7": "седьмой;",
        "8": "восьмой;",
        "9": "девятый;",
        "10": "десятый;",
        "11": "одиннадцатый;",
        "12": "двенадцатый;",
        "13": "тринадцатый;",
        "14": "четырнадцатый;",
        "15": "пятнадцатый;",
        "16": "шестнадцатый;",
        "17": "семнадцатый;",
        "18": "восемнадцатый;",
        "19": "девятнадцатый;",
        "20": "двадцатый;",
        "(21, 29)": "двадцать >>;",
        "30": "тридцатый;",
        "(31, 39)": "тридцать >>;",
        "40": "сороковой;",
        "(41, 49)": "сорок >>;",
        "50": "пятидесятый;",
        "(51, 59)": "пятьдесят >>;",
        "60": "шестидесятый;",
        "(61, 69)": "шестьдесят >>;",
        "70": "семидесятый;",
        "(71, 79)": "семьдесят >>;",
        "80": "восьмидесятый;",
        "(81, 89)": "восемьдесят >>;",
        "90": "девяностый;",
        "(91, 99)": "девяносто >>;",
        "100": "сотый;",
        "(101, 199)": "сто >>;",
        "(200, 299)": "<%spellout-cardinal-feminine<сти[ >>];",
        "(300, 499)": "<%spellout-cardinal-feminine<ста[ >>];",
        "(500, 999)": "<%spellout-cardinal-feminine<сот[ >>];",
        "1000": "тысяч>%%yj>;",
        "(1001, 21000)": "одна тысяч>%%yj>;",
        "(21001, 'inf')": "=0=.;"
    },
    "%spellout-ordinal-masculine-ablative": {
        "0": "нулевым;",
        "1": "первым;",
        "2": "вторым;",
        "3": "третьим;",
        "4": "четвертым;",
        "5": "пятым;",
        "6": "шестым;",
        "7": "седьмым;",
        "8": "восьмым;",
        "9": "девятым;",
        "10": "десятым;",
        "11": "одиннадцатым;",
        "12": "двенадцатым;",
        "13": "тринадцатым;",
        "14": "четырнадцатым;",
        "15": "пятнадцатым;",
        "16": "шестнадцатым;",
        "17": "семнадцатым;",
        "18": "восемнадцатым;",
        "19": "девятнадцатым;",
        "20": "двадцатым;",
        "(21, 29)": "двадцать >>;",
        "30": "тридцатым;",
        "(31, 39)": "тридцать >>;",
        "40": "сороковым;",
        "(41, 49)": "сорок >>;",
        "50": "пятидесятым;",
        "(51, 59)": "пятьдесят >>;",
        "60": "шестидесятым;",
        "(61, 69)": "шестьдесят >>;",
        "70": "семидесятым;",
        "(71, 79)": "семьдесят >>;",
        "80": "восьмидесятым;",
        "(81, 89)": "восемьдесят >>;",
        "90": "девяностым;",
        "(91, 99)": "девяносто >>;",
        "100": "сотым;",
        "(101, 199)": "сто >>;",
        "(200, 299)": "<%spellout-cardinal-feminine<сти[ >>];",
        "(300, 499)": "<%spellout-cardinal-feminine<ста[ >>];",
        "(500, 999)": "<%spellout-cardinal-feminine<сот[ >>];",
        "1000": "тысяч>%%ym>;",
        "(1001, 21000)": "одна тысяч>%%ym>;",
        "(21001, 'inf')": "=0=.;"
    },
    "%spellout-ordinal-masculine-accusative": {
        "(0, 'inf')": "=%spellout-ordinal-masculine=;"
    },
    "%spellout-ordinal-masculine-dative": {
        "0": "нулевому;",
        "1": "первому;",
        "2": "второму;",
        "3": "третьому;",
        "4": "четвертому;",
        "5": "пятому;",
        "6": "шестому;",
        "7": "седьмому;",
        "8": "восьмому;",
        "9": "девятому;",
        "10": "десятому;",
        "11": "одиннадцатому;",
        "12": "двенадцатому;",
        "13": "тринадцатому;",
        "14": "четырнадцатому;",
        "15": "пятнадцатому;",
        "16": "шестнадцатому;",
        "17": "семнадцатому;",
        "18": "восемнадцатому;",
        "19": "девятнадцатому;",
        "20": "двадцатому;",
        "(21, 29)": "двадцать >>;",
        "30": "тридцатому;",
        "(31, 39)": "тридцать >>;",
        "40": "сороковому;",
        "(41, 49)": "сорок >>;",
        "50": "пятидесятому;",
        "(51, 59)": "пятьдесят >>;",
        "60": "шестидесятому;",
        "(61, 69)": "шестьдесят >>;",
        "70": "семидесятому;",
        "(71, 79)": "семьдесят >>;",
        "80": "восемьдесятому;",
        "(81, 89)": "восемьдесят >>;",
        "90": "девяностому;",
        "(91, 99)": "девяносто >>;",
        "100": "сотому;",
        "(101, 199)": "сто >>;",
        "(200, 299)": "<%spellout-cardinal-feminine<сти[ >>];",
        "(300, 499)": "<%spellout-cardinal-feminine<ста[ >>];",
        "(500, 999)": "<%spellout-cardinal-feminine<сот[ >>];",
        "1000": "тысяч>%%omu>;",
        "(1001, 21000)": "одна тысяч>%%omu>;",
        "(21001, 'inf')": "=0=.;"
    },
    "%spellout-ordinal-masculine-genitive": {
        "0": "нулевого;",
        "1": "первого;",
        "2": "второго;",
        "3": "третьего;",
        "4": "четвертого;",
        "5": "пятого;",
        "6": "шестого;",
        "7": "седьмого;",
        "8": "восьмого;",
        "9": "девятого;",
        "10": "десятого;",
        "11": "одиннадцатого;",
        "12": "двенадцатого;",
        "13": "тринадцатого;",
        "14": "четырнадцатого;",
        "15": "пятнадцатого;",
        "16": "шестнадцатого;",
        "17": "семнадцатого;",
        "18": "восемнадцатого;",
        "19": "девятнадцатого;",
        "20": "двадцатого;",
        "(21, 29)": "двадцать >>;",
        "30": "тридцатого;",
        "(31, 39)": "тридцать >>;",
        "40": "сорокового;",
        "(41, 49)": "сорок >>;",
        "50": "пятидесятого;",
        "(51, 59)": "пятьдесят >>;",
        "60": "шестидесятого;",
        "(61, 69)": "шестьдесят >>;",
        "70": "семидесятого;",
        "(71, 79)": "семьдесят >>;",
        "80": "восьмидесятого;",
        "(81, 89)": "восемьдесят >>;",
        "90": "девяностого;",
        "(91, 99)": "девяносто >>;",
        "100": "сотого;",
        "(101, 199)": "сто >>;",
        "(200, 299)": "<%spellout-cardinal-feminine<сти[ >>];",
        "(300, 499)": "<%spellout-cardinal-feminine<ста[ >>];",
        "(500, 999)": "<%spellout-cardinal-feminine<сот[ >>];",
        "1000": "тысяч>%%ogo>;",
        "(1001, 21000)": "одна тысяч>%%ogo>;",
        "(21001, 'inf')": "=0=.;"
    },
    "%spellout-ordinal-masculine-locative": {
        "0": "нулевом;",
        "1": "первом;",
        "2": "втором;",
        "3": "третьем;",
        "4": "четвертом;",
        "5": "пятом;",
        "6": "шестом;",
        "7": "седьмом;",
        "8": "восьмом;",
        "9": "девятом;",
        "10": "десятом;",
        "11": "одиннадцатом;",
        "12": "двенадцатом;",
        "13": "тринадцатом;",
        "14": "четырнадцатом;",
        "15": "пятнадцатом;",
        "16": "шестнадцатом;",
        "17": "семнадцатом;",
        "18": "восемнадцатом;",
        "19": "девятнадцатом;",
        "20": "двадцатом;",
        "(21, 29)": "двадцать >>;",
        "30": "тридцатом;",
        "(31, 39)": "тридцать >>;",
        "40": "сороковой;",
        "(41, 49)": "сорок >>;",
        "50": "пятидесятом;",
        "(51, 59)": "пятьдесят >>;",
        "60": "шестидесятом;",
        "(61, 69)": "шестьдесят >>;",
        "70": "семидесятом;",
        "(71, 79)": "семьдесят >>;",
        "80": "восьмидесятом;",
        "(81, 89)": "восемьдесят >>;",
        "90": "девяностом;",
        "(91, 99)": "девяносто >>;",
        "100": "сотом;",
        "(101, 199)": "сто >>;",
        "(200, 299)": "<%spellout-cardinal-feminine<сти[ >>];",
        "(300, 499)": "<%spellout-cardinal-feminine<ста[ >>];",
        "(500, 999)": "<%spellout-cardinal-feminine<сот[ >>];",
        "1000": "тысяч>%%om>;",
        "(1001, 21000)": "одна тысяч>%%om>;",
        "(21001, 'inf')": "=0=.;"
    },
    "%spellout-ordinal-neuter": {
        "0": "нулевое;",
        "1": "первое;",
        "2": "второе;",
        "3": "третье;",
        "4": "четвертое;",
        "5": "пятое;",
        "6": "шестое;",
        "7": "седьмое;",
        "8": "восьмое;",
        "9": "девятое;",
        "10": "десятое;",
        "11": "одиннадцатое;",
        "12": "двенадцатое;",
        "13": "тринадцатое;",
        "14": "четырнадцатое;",
        "15": "пятнадцатое;",
        "16": "шестнадцатое;",
        "17": "семнадцатое;",
        "18": "восемнадцатое;",
        "19": "девятнадцатое;",
        "20": "двадцатое;",
        "(21, 29)": "двадцать >>;",
        "30": "тридцатое;",
        "(31, 39)": "тридцать >>;",
        "40": "сороковое;",
        "(41, 49)": "сорок >>;",
        "50": "пятидесятое;",
        "(51, 59)": "пятьдесят >>;",
        "60": "шестидесятое;",
        "(61, 69)": "шестьдесят >>;",
        "70": "семидесятое;",
        "(71, 79)": "семьдесят >>;",
        "80": "восемьдесятое;",
        "(81, 89)": "восемьдесят >>;",
        "90": "девяностое;",
        "(91, 99)": "девяносто >>;",
        "100": "сотое;",
        "(101, 199)": "сто >>;",
        "(200, 299)": "<%spellout-cardinal-feminine<сти[ >>];",
        "(300, 499)": "<%spellout-cardinal-feminine<ста[ >>];",
        "(500, 999)": "<%spellout-cardinal-feminine<сот[ >>];",
        "1000": "тысяч>%%oe>;",
        "(1001, 21000)": "одна тысяч>%%oe>;",
        "(21001, 'inf')": "=0=.;"
    },
    "%spellout-ordinal-neuter-ablative": {
        "(0, 'inf')": "=%spellout-ordinal-masculine-ablative=;"
    },
    "%spellout-ordinal-neuter-accusative": {
        "(0, 'inf')": "=%spellout-ordinal-neuter=;"
    },
    "%spellout-ordinal-neuter-dative": {
        "(0, 'inf')": "=%spellout-ordinal-masculine-dative=;"
    },
    "%spellout-ordinal-neuter-genitive": {
        "(0, 'inf')": "=%spellout-ordinal-masculine-genitive=;"
    },
    "%spellout-ordinal-neuter-locative": {
        "(0, 'inf')": "=%spellout-ordinal-masculine-locative=;"
    },
    "%spellout-ordinal-plural": {
        "0": "нулевые;",
        "1": "первые;",
        "2": "вторые;",
        "3": "третьи;",
        "4": "четвертые;",
        "5": "пятые;",
        "6": "шестые;",
        "7": "седьмые;",
        "8": "восьмые;",
        "9": "девятые;",
        "10": "десятые;",
        "11": "одиннадцатые;",
        "12": "двенадцатые;",
        "13": "тринадцатые;",
        "14": "четырнадцатые;",
        "15": "пятнадцатые;",
        "16": "шестнадцатые;",
        "17": "семнадцатые;",
        "18": "восемнадцатые;",
        "19": "девятнадцатые;",
        "20": "двадцатые;",
        "(21, 29)": "двадцать >>;",
        "30": "тридцатые;",
        "(31, 39)": "тридцать >>;",
        "40": "сороковые;",
        "(41, 49)": "сорок >>;",
        "50": "пятидесятые;",
        "(51, 59)": "пятьдесят >>;",
        "60": "шестидесятые;",
        "(61, 69)": "шестьдесят >>;",
        "70": "семидесятые;",
        "(71, 79)": "семьдесят >>;",
        "80": "восемьдесятые;",
        "(81, 89)": "восемьдесят >>;",
        "90": "девяностые;",
        "(91, 99)": "девяносто >>;",
        "100": "сотые;",
        "(101, 199)": "сто >>;",
        "(200, 299)": "<%spellout-cardinal-feminine<сти[ >>];",
        "(300, 499)": "<%spellout-cardinal-feminine<ста[ >>];",
        "(500, 999)": "<%spellout-cardinal-feminine<сот[ >>];",
        "1000": "тысяч>%%ye>;",
        "(1001, 21000)": "одна тысяч>%%ye>;",
        "(21001, 'inf')": "=0=.;"
    },
    "%spellout-ordinal-plural-ablative": {
        "0": "нулевыми;",
        "1": "первыми;",
        "2": "вторыми;",
        "3": "третьими;",
        "4": "четвертыми;",
        "5": "пятыми;",
        "6": "шестыми;",
        "7": "седьмыми;",
        "8": "восьмыми;",
        "9": "девятыми;",
        "10": "десятыми;",
        "11": "одиннадцатыми;",
        "12": "двенадцатыми;",
        "13": "тринадцатыми;",
        "14": "четырнадцатыми;",
        "15": "пятнадцатыми;",
        "16": "шестнадцатыми;",
        "17": "семнадцатыми;",
        "18": "восемнадцатыми;",
        "19": "девятнадцатыми;",
        "20": "двадцатыми;",
        "(21, 29)": "двадцать >>;",
        "30": "тридцатыми;",
        "(31, 39)": "тридцать >>;",
        "40": "сороковой;",
        "(41, 49)": "сорок >>;",
        "50": "пятидесятыми;",
        "(51, 59)": "пятьдесят >>;",
        "60": "шестидесятыми;",
        "(61, 69)": "шестьдесят >>;",
        "70": "семидесятыми;",
        "(71, 79)": "семьдесят >>;",
        "80": "восьмидесятыми;",
        "(81, 89)": "восемьдесят >>;",
        "90": "девяностыми;",
        "(91, 99)": "девяносто >>;",
        "100": "сотыми;",
        "(101, 199)": "сто >>;",
        "(200, 299)": "<%spellout-cardinal-feminine<сти[ >>];",
        "(300, 499)": "<%spellout-cardinal-feminine<ста[ >>];",
        "(500, 999)": "<%spellout-cardinal-feminine<сот[ >>];",
        "1000": "тысяч>%%ymi>;",
        "(1001, 21000)": "одна тысяч>%%ymi>;",
        "(21001, 'inf')": "=0=.;"
    },
    "%spellout-ordinal-plural-accusative": {
        "(0, 'inf')": "=%spellout-ordinal-plural=;"
    },
    "%spellout-ordinal-plural-dative": {
        "(0, 'inf')": "=%spellout-ordinal-masculine-ablative=;"
    },
    "%spellout-ordinal-plural-genitive": {
        "0": "нулевых;",
        "1": "первых;",
        "2": "вторых;",
        "3": "третьих;",
        "4": "четвертых;",
        "5": "пятых;",
        "6": "шестых;",
        "7": "седьмых;",
        "8": "восьмых;",
        "9": "девятых;",
        "10": "десятых;",
        "11": "одиннадцатых;",
        "12": "двенадцатых;",
        "13": "тринадцатых;",
        "14": "четырнадцатых;",
        "15": "пятнадцатых;",
        "16": "шестнадцатых;",
        "17": "семнадцатых;",
        "18": "восемнадцатых;",
        "19": "девятнадцатых;",
        "20": "двадцатых;",
        "(21, 29)": "двадцать >>;",
        "30": "тридцатых;",
        "(31, 39)": "тридцать >>;",
        "40": "сороковых;",
        "(41, 49)": "сорок >>;",
        "50": "пятидесятых;",
        "(51, 59)": "пятьдесят >>;",
        "60": "шестидесятых;",
        "(61, 69)": "шестьдесят >>;",
        "70": "семидесятых;",
        "(71, 79)": "семьдесят >>;",
        "80": "восьмидесятых;",
        "(81, 89)": "восемьдесят >>;",
        "90": "девяностых;",
        "(91, 99)": "девяносто >>;",
        "100": "сотых;",
        "(101, 199)": "сто >>;",
        "(200, 299)": "<%spellout-cardinal-feminine<сти[ >>];",
        "(300, 499)": "<%spellout-cardinal-feminine<ста[ >>];",
        "(500, 999)": "<%spellout-cardinal-feminine<сот[ >>];",
        "1000": "тысяч>%%yh>;",
        "(1001, 21000)": "одна тысяч>%%yh>;",
        "(21001, 'inf')": "=0=.;"
    },
    "%spellout-ordinal-plural-locative": {
        "(0, 'inf')": "=%spellout-ordinal-plural-genitive=;"
    }
}



# -*- coding: utf-8 -*-
info = {
    "name": "az-Latn",
    "date_order": "DMY",
    "january": [
        "yanvar",
        "yan"
    ],
    "february": [
        "fevral",
        "fev"
    ],
    "march": [
        "mart",
        "mar"
    ],
    "april": [
        "aprel",
        "apr"
    ],
    "may": [
        "may"
    ],
    "june": [
        "iyun",
        "iyn"
    ],
    "july": [
        "iyul",
        "iyl"
    ],
    "august": [
        "avqust",
        "avq"
    ],
    "september": [
        "sentyabr",
        "sen"
    ],
    "october": [
        "oktyabr",
        "okt"
    ],
    "november": [
        "noyabr",
        "noy"
    ],
    "december": [
        "dekabr",
        "dek"
    ],
    "monday": [
        "bazar ertəsi",
        "be"
    ],
    "tuesday": [
        "çərşənbə axşamı",
        "ça"
    ],
    "wednesday": [
        "çərşənbə",
        "ç"
    ],
    "thursday": [
        "cümə axşamı",
        "ca"
    ],
    "friday": [
        "cümə",
        "c"
    ],
    "saturday": [
        "şənbə",
        "ş"
    ],
    "sunday": [
        "bazar",
        "b"
    ],
    "am": [
        "am"
    ],
    "pm": [
        "pm"
    ],
    "year": [
        "il"
    ],
    "month": [
        "ay"
    ],
    "week": [
        "həftə"
    ],
    "day": [
        "gün"
    ],
    "hour": [
        "saat"
    ],
    "minute": [
        "dəqiqə",
        "dəq"
    ],
    "second": [
        "saniyə",
        "san"
    ],
    "relative-type": {
        "1 year ago": [
            "keçən il"
        ],
        "0 year ago": [
            "bu il"
        ],
        "in 1 year": [
            "gələn il"
        ],
        "1 month ago": [
            "keçən ay"
        ],
        "0 month ago": [
            "bu ay"
        ],
        "in 1 month": [
            "gələn ay"
        ],
        "1 week ago": [
            "keçən həftə"
        ],
        "0 week ago": [
            "bu həftə"
        ],
        "in 1 week": [
            "gələn həftə"
        ],
        "1 day ago": [
            "dünən"
        ],
        "0 day ago": [
            "bu gün"
        ],
        "in 1 day": [
            "sabah"
        ],
        "0 hour ago": [
            "bu saat"
        ],
        "0 minute ago": [
            "bu dəqiqə"
        ],
        "0 second ago": [
            "indi"
        ]
    },
    "relative-type-regex": {
        "in \\1 year": [
            "(\\d+) il ərzində"
        ],
        "\\1 year ago": [
            "(\\d+) il öncə"
        ],
        "in \\1 month": [
            "(\\d+) ay ərzində"
        ],
        "\\1 month ago": [
            "(\\d+) ay öncə"
        ],
        "in \\1 week": [
            "(\\d+) həftə ərzində"
        ],
        "\\1 week ago": [
            "(\\d+) həftə öncə"
        ],
        "in \\1 day": [
            "(\\d+) gün ərzində"
        ],
        "\\1 day ago": [
            "(\\d+) gün öncə"
        ],
        "in \\1 hour": [
            "(\\d+) saat ərzində"
        ],
        "\\1 hour ago": [
            "(\\d+) saat öncə"
        ],
        "in \\1 minute": [
            "(\\d+) dəqiqə ərzində"
        ],
        "\\1 minute ago": [
            "(\\d+) dəqiqə öncə"
        ],
        "in \\1 second": [
            "(\\d+) saniyə ərzində"
        ],
        "\\1 second ago": [
            "(\\d+) saniyə öncə"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}



# -*- coding: utf-8 -*-
info = {
    "name": "ka",
    "date_order": "DMY",
    "january": [
        "იანვარი",
        "იან"
    ],
    "february": [
        "თებერვალი",
        "თებ"
    ],
    "march": [
        "მარტი",
        "მარ"
    ],
    "april": [
        "აპრილი",
        "აპრ"
    ],
    "may": [
        "მაისი",
        "მაი"
    ],
    "june": [
        "ივნისი",
        "ივნ"
    ],
    "july": [
        "ივლისი",
        "ივლ"
    ],
    "august": [
        "აგვისტო",
        "აგვ"
    ],
    "september": [
        "სექტემბერი",
        "სექ"
    ],
    "october": [
        "ოქტომბერი",
        "ოქტ"
    ],
    "november": [
        "ნოემბერი",
        "ნოე"
    ],
    "december": [
        "დეკემბერი",
        "დეკ"
    ],
    "monday": [
        "ორშაბათი",
        "ორშ"
    ],
    "tuesday": [
        "სამშაბათი",
        "სამ"
    ],
    "wednesday": [
        "ოთხშაბათი",
        "ოთხ"
    ],
    "thursday": [
        "ხუთშაბათი",
        "ხუთ"
    ],
    "friday": [
        "პარასკევი",
        "პარ"
    ],
    "saturday": [
        "შაბათი",
        "შაბ"
    ],
    "sunday": [
        "კვირა",
        "კვი"
    ],
    "am": [
        "am"
    ],
    "pm": [
        "შუადღ შემდეგ",
        "pm"
    ],
    "year": [
        "წელი",
        "წ",
        "წლის"
    ],
    "month": [
        "თვე"
    ],
    "week": [
        "კვირა",
        "კვ"
    ],
    "day": [
        "დღე"
    ],
    "hour": [
        "საათი",
        "სთ"
    ],
    "minute": [
        "წუთი",
        "წთ"
    ],
    "second": [
        "წამი",
        "წმ"
    ],
    "relative-type": {
        "1 year ago": [
            "გასულ წელს"
        ],
        "0 year ago": [
            "ამ წელს"
        ],
        "in 1 year": [
            "მომავალ წელს"
        ],
        "1 month ago": [
            "გასულ თვეს"
        ],
        "0 month ago": [
            "ამ თვეში"
        ],
        "in 1 month": [
            "მომავალ თვეს"
        ],
        "1 week ago": [
            "გასულ კვირაში"
        ],
        "0 week ago": [
            "ამ კვირაში"
        ],
        "in 1 week": [
            "მომავალ კვირაში"
        ],
        "1 day ago": [
            "გუშინ"
        ],
        "0 day ago": [
            "დღეს"
        ],
        "in 1 day": [
            "ხვალ"
        ],
        "0 hour ago": [
            "ამ საათში"
        ],
        "0 minute ago": [
            "ამ წუთში"
        ],
        "0 second ago": [
            "ახლა"
        ]
    },
    "relative-type-regex": {
        "in \\1 year": [
            "(\\d+) წელიწადში",
            "(\\d+) წელში"
        ],
        "\\1 year ago": [
            "(\\d+) წლის წინ"
        ],
        "in \\1 month": [
            "(\\d+) თვეში"
        ],
        "\\1 month ago": [
            "(\\d+) თვის წინ"
        ],
        "in \\1 week": [
            "(\\d+) კვირაში"
        ],
        "\\1 week ago": [
            "(\\d+) კვირის წინ",
            "(\\d+) კვ წინ"
        ],
        "in \\1 day": [
            "(\\d+) დღეში"
        ],
        "\\1 day ago": [
            "(\\d+) დღის წინ"
        ],
        "in \\1 hour": [
            "(\\d+) საათში"
        ],
        "\\1 hour ago": [
            "(\\d+) საათის წინ",
            "(\\d+) სთ წინ"
        ],
        "in \\1 minute": [
            "(\\d+) წუთში"
        ],
        "\\1 minute ago": [
            "(\\d+) წუთის წინ",
            "(\\d+) წთ წინ"
        ],
        "in \\1 second": [
            "(\\d+) წამში"
        ],
        "\\1 second ago": [
            "(\\d+) წამის წინ",
            "(\\d+) წმ წინ"
        ]
    },
    "locale_specific": {},
    "skip": [
        "ის",
        "ზე",
        "დაახლოებით",
        "და",
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ],
    "sentence_splitter_group": 1,
    "ago": [
        "წინ"
    ],
    "in": [
        "დღეიდან"
    ],
    "simplifications": [
        {
            "ერთ": "1"
        }
    ]
}



# -*- coding: utf-8 -*-
info = {
    "name": "el",
    "date_order": "DMY",
    "january": [
        "ιανουάριος",
        "ιαν",
        "ιανουαρίου"
    ],
    "february": [
        "φεβρουάριος",
        "φεβ",
        "φεβρουαρίου"
    ],
    "march": [
        "μάρτιος",
        "μάρ",
        "μαρτίου",
        "μαρ"
    ],
    "april": [
        "απρίλιος",
        "απρ",
        "απριλίου"
    ],
    "may": [
        "μάιος",
        "μάι",
        "μαΐου",
        "μαΐ"
    ],
    "june": [
        "ιούνιος",
        "ιούν",
        "ιουνίου",
        "ιουν"
    ],
    "july": [
        "ιούλιος",
        "ιούλ",
        "ιουλίου",
        "ιουλ"
    ],
    "august": [
        "αύγουστος",
        "αύγ",
        "αυγούστου",
        "αυγ"
    ],
    "september": [
        "σεπτέμβριος",
        "σεπ",
        "σεπτεμβρίου"
    ],
    "october": [
        "οκτώβριος",
        "οκτ",
        "οκτωβρίου"
    ],
    "november": [
        "νοέμβριος",
        "νοέ",
        "νοεμβρίου",
        "νοε"
    ],
    "december": [
        "δεκέμβριος",
        "δεκ",
        "δεκεμβρίου"
    ],
    "monday": [
        "δευτέρα",
        "δευ"
    ],
    "tuesday": [
        "τρίτη",
        "τρί"
    ],
    "wednesday": [
        "τετάρτη",
        "τετ"
    ],
    "thursday": [
        "πέμπτη",
        "πέμ"
    ],
    "friday": [
        "παρασκευή",
        "παρ"
    ],
    "saturday": [
        "σάββατο",
        "σάβ"
    ],
    "sunday": [
        "κυριακή",
        "κυρ"
    ],
    "am": [
        "πμ"
    ],
    "pm": [
        "μμ"
    ],
    "year": [
        "έτος",
        "έτ"
    ],
    "month": [
        "μήνας",
        "μήν"
    ],
    "week": [
        "εβδομάδα",
        "εβδ"
    ],
    "day": [
        "ημέρα"
    ],
    "hour": [
        "ώρα",
        "ώρ",
        "ώ"
    ],
    "minute": [
        "λεπτό",
        "λεπ",
        "λ"
    ],
    "second": [
        "δευτερόλεπτο",
        "δευτ",
        "δ"
    ],
    "relative-type": {
        "1 year ago": [
            "πέρσι"
        ],
        "0 year ago": [
            "φέτος"
        ],
        "in 1 year": [
            "επόμενο έτος"
        ],
        "1 month ago": [
            "προηγούμενος μήνας"
        ],
        "0 month ago": [
            "τρέχων μήνας"
        ],
        "in 1 month": [
            "επόμενος μήνας"
        ],
        "1 week ago": [
            "προηγούμενη εβδομάδα"
        ],
        "0 week ago": [
            "αυτήν την εβδομάδα"
        ],
        "in 1 week": [
            "επόμενη εβδομάδα"
        ],
        "1 day ago": [
            "χθες"
        ],
        "0 day ago": [
            "σήμερα"
        ],
        "in 1 day": [
            "αύριο"
        ],
        "0 hour ago": [
            "αυτήν την ώρα"
        ],
        "0 minute ago": [
            "αυτό το λεπτό"
        ],
        "0 second ago": [
            "τώρα"
        ]
    },
    "relative-type-regex": {
        "in \\1 year": [
            "σε (\\d+) έτος",
            "σε (\\d+) έτη"
        ],
        "\\1 year ago": [
            "πριν από (\\d+) έτος",
            "πριν από (\\d+) έτη",
            "(\\d+) έτος πριν",
            "(\\d+) έτη πριν"
        ],
        "in \\1 month": [
            "σε (\\d+) μήνα",
            "σε (\\d+) μήνες",
            "σε (\\d+) μ"
        ],
        "\\1 month ago": [
            "πριν από (\\d+) μήνα",
            "πριν από (\\d+) μήνες",
            "(\\d+) μ πριν"
        ],
        "in \\1 week": [
            "σε (\\d+) εβδομάδα",
            "σε (\\d+) εβδομάδες",
            "σε (\\d+) εβδ"
        ],
        "\\1 week ago": [
            "πριν από (\\d+) εβδομάδα",
            "πριν από (\\d+) εβδομάδες",
            "πριν από (\\d+) εβδ",
            "(\\d+) εβδ πριν"
        ],
        "in \\1 day": [
            "σε (\\d+) ημέρα",
            "σε (\\d+) ημέρες",
            "σε (\\d+) ημ"
        ],
        "\\1 day ago": [
            "πριν από (\\d+) ημέρα",
            "πριν από (\\d+) ημέρες",
            "(\\d+) ημ πριν"
        ],
        "in \\1 hour": [
            "σε (\\d+) ώρα",
            "σε (\\d+) ώρες",
            "σε (\\d+) ώρ",
            "σε (\\d+) ώ"
        ],
        "\\1 hour ago": [
            "πριν από (\\d+) ώρα",
            "πριν από (\\d+) ώρες",
            "πριν από (\\d+) ώρ",
            "(\\d+) ώ πριν"
        ],
        "in \\1 minute": [
            "σε (\\d+) λεπτό",
            "σε (\\d+) λεπτά",
            "σε (\\d+) λεπ",
            "σε (\\d+) λ"
        ],
        "\\1 minute ago": [
            "πριν από (\\d+) λεπτό",
            "πριν από (\\d+) λεπτά",
            "πριν από (\\d+) λεπ",
            "(\\d+) λ πριν"
        ],
        "in \\1 second": [
            "σε (\\d+) δευτερόλεπτο",
            "σε (\\d+) δευτερόλεπτα",
            "σε (\\d+) δευτ",
            "σε (\\d+) δ"
        ],
        "\\1 second ago": [
            "πριν από (\\d+) δευτερόλεπτο",
            "πριν από (\\d+) δευτερόλεπτα",
            "πριν από (\\d+) δευτ",
            "(\\d+) δ πριν"
        ]
    },
    "locale_specific": {
        "el-CY": {
            "name": "el-CY"
        }
    },
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}



# -*- coding: utf-8 -*-
import regex as re
import json
import os
from collections import OrderedDict

from dateparser_scripts.utils import get_raw_data

os.chdir(os.path.dirname(os.path.abspath(__file__)))
get_raw_data()

# Languages with insufficient translation data are excluded
avoid_languages = ['cu', 'kkj', 'nds', 'prg', 'tk', 'vai', 'vai-Latn', 'vai-Vaii', 'vo']


def _get_language_locale_dict():
    cldr_dates_full_dir = "../raw_data/cldr_dates_full/main/"
    available_locale_names = os.listdir(cldr_dates_full_dir)
    available_language_names = [shortname for shortname in available_locale_names
                                if not re.search(r'-[A-Z0-9]+$', shortname)]
    available_language_names.remove('root')
    language_locale_dict = {}
    for language_name in available_language_names:
        language_locale_dict[language_name] = []
        for locale_name in available_locale_names:
            if re.match(language_name + '-[A-Z0-9]+$', locale_name):
                language_locale_dict[language_name].append(locale_name)

    for language in avoid_languages:
        del language_locale_dict[language]
    return language_locale_dict


language_locale_dict = _get_language_locale_dict()


def _get_language_order():
    territory_info_file = "../raw_data/cldr_core/supplemental/territoryInfo.json"
    with open(territory_info_file) as f:
        territory_content = json.load(f)
    territory_info_data = territory_content["supplemental"]["territoryInfo"]

    language_population_dict = {}
    for territory in territory_info_data:
        population = int(territory_info_data[territory]["_population"])
        try:
            lang_dict = territory_info_data[territory]["languagePopulation"]
            for language in lang_dict:
                language_population = float(lang_dict[language]["_populationPercent"]) * population
                if language in language_population_dict:
                    language_population_dict[language] += language_population
                else:
                    language_population_dict[language] = language_population
        except:
            pass

    language_order = sorted(language_population_dict.keys(),
                            key=lambda x: (language_population_dict[x], x), reverse=True)
    for index in range(0, len(language_order)):
        language_order[index] = re.sub(r'_', r'-', language_order[index])

    cldr_languages = language_locale_dict.keys()
    supplementary_date_directory = "../dateparser_data/supplementary_language_data/date_translation_data"
    supplementary_languages = [x[:-5] for x in os.listdir(supplementary_date_directory)]
    available_languages = set(cldr_languages).union(set(supplementary_languages))
    language_order = [shortname for shortname in language_order if shortname in available_languages]
    absent_languages = set(available_languages) - set(language_order)
    remaining_languages = []
    for language in absent_languages:
        parent_language = re.sub(r'-\w+', '', language)
        if parent_language in language_order:
            language_order.insert(language_order.index(parent_language) + 1, language)
        else:
            remaining_languages.append(language)
    language_order = language_order + sorted(remaining_languages)
    language_order = list(map(str, language_order))
    return language_order


language_order = _get_language_order()


def main():
    encoding_comment = "# -*- coding: utf-8 -*-\n"
    parent_directory = "../dateparser/data/"
    filename = "../dateparser/data/languages_info.py"
    if not os.path.isdir(parent_directory):
        os.mkdir(parent_directory)
    language_order_string = 'language_order = ' + json.dumps(
            language_order, separators=(',', ': '), indent=4)

    complete_language_locale_dict = OrderedDict()
    for key in language_order:
        if key in language_locale_dict.keys():
            complete_language_locale_dict[key] = sorted(language_locale_dict[key])
        else:
            complete_language_locale_dict[key] = []

    language_locale_dict_string = 'language_locale_dict = ' + json.dumps(
            complete_language_locale_dict, separators=(',', ': '), indent=4)
    languages_info_string = language_order_string + '\n\n' + language_locale_dict_string
    with open(filename, 'w') as f:
        f.write(encoding_comment + languages_info_string)


if __name__ == '__main__':
    main()



# -*- coding: utf-8 -*-
info = {
    "name": "eu",
    "date_order": "YMD",
    "january": [
        "urtarrila",
        "urt"
    ],
    "february": [
        "otsaila",
        "ots"
    ],
    "march": [
        "martxoa",
        "mar"
    ],
    "april": [
        "apirila",
        "api"
    ],
    "may": [
        "maiatza",
        "mai"
    ],
    "june": [
        "ekaina",
        "eka"
    ],
    "july": [
        "uztaila",
        "uzt"
    ],
    "august": [
        "abuztua",
        "abu"
    ],
    "september": [
        "iraila",
        "ira"
    ],
    "october": [
        "urria",
        "urr"
    ],
    "november": [
        "azaroa",
        "aza"
    ],
    "december": [
        "abendua",
        "abe"
    ],
    "monday": [
        "astelehena",
        "al"
    ],
    "tuesday": [
        "asteartea",
        "ar"
    ],
    "wednesday": [
        "asteazkena",
        "az"
    ],
    "thursday": [
        "osteguna",
        "og"
    ],
    "friday": [
        "ostirala",
        "or"
    ],
    "saturday": [
        "larunbata",
        "lr"
    ],
    "sunday": [
        "igandea",
        "ig"
    ],
    "am": [
        "am"
    ],
    "pm": [
        "pm"
    ],
    "year": [
        "urtea"
    ],
    "month": [
        "hilabetea",
        "hil"
    ],
    "week": [
        "astea",
        "ast"
    ],
    "day": [
        "eguna",
        "eg"
    ],
    "hour": [
        "ordua",
        "h"
    ],
    "minute": [
        "minutua",
        "min"
    ],
    "second": [
        "segundoa",
        "s"
    ],
    "relative-type": {
        "1 year ago": [
            "aurreko urtea"
        ],
        "0 year ago": [
            "aurten"
        ],
        "in 1 year": [
            "hurrengo urtea"
        ],
        "1 month ago": [
            "aurreko hilabetea"
        ],
        "0 month ago": [
            "hilabete hau"
        ],
        "in 1 month": [
            "hurrengo hilabetea"
        ],
        "1 week ago": [
            "aurreko astea"
        ],
        "0 week ago": [
            "aste hau"
        ],
        "in 1 week": [
            "hurrengo astea"
        ],
        "1 day ago": [
            "atzo"
        ],
        "0 day ago": [
            "gaur"
        ],
        "in 1 day": [
            "bihar"
        ],
        "0 hour ago": [
            "ordu honetan"
        ],
        "0 minute ago": [
            "minutu honetan"
        ],
        "0 second ago": [
            "orain"
        ]
    },
    "relative-type-regex": {
        "in \\1 year": [
            "(\\d+) urte barru"
        ],
        "\\1 year ago": [
            "duela (\\d+) urte"
        ],
        "in \\1 month": [
            "(\\d+) hilabete barru"
        ],
        "\\1 month ago": [
            "duela (\\d+) hilabete"
        ],
        "in \\1 week": [
            "(\\d+) aste barru"
        ],
        "\\1 week ago": [
            "duela (\\d+) aste"
        ],
        "in \\1 day": [
            "(\\d+) egun barru"
        ],
        "\\1 day ago": [
            "duela (\\d+) egun"
        ],
        "in \\1 hour": [
            "(\\d+) ordu barru"
        ],
        "\\1 hour ago": [
            "duela (\\d+) ordu"
        ],
        "in \\1 minute": [
            "(\\d+) minutu barru"
        ],
        "\\1 minute ago": [
            "duela (\\d+) minutu"
        ],
        "in \\1 second": [
            "(\\d+) segundo barru"
        ],
        "\\1 second ago": [
            "duela (\\d+) segundo"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}



# -*- coding: utf-8 -*-
info = {
    "name": "rm",
    "date_order": "DMY",
    "january": [
        "schaner",
        "schan"
    ],
    "february": [
        "favrer",
        "favr"
    ],
    "march": [
        "mars"
    ],
    "april": [
        "avrigl",
        "avr"
    ],
    "may": [
        "matg"
    ],
    "june": [
        "zercladur",
        "zercl"
    ],
    "july": [
        "fanadur",
        "fan"
    ],
    "august": [
        "avust"
    ],
    "september": [
        "settember",
        "sett"
    ],
    "october": [
        "october",
        "oct"
    ],
    "november": [
        "november",
        "nov"
    ],
    "december": [
        "december",
        "dec"
    ],
    "monday": [
        "glindesdi",
        "gli"
    ],
    "tuesday": [
        "mardi",
        "ma"
    ],
    "wednesday": [
        "mesemna",
        "me"
    ],
    "thursday": [
        "gievgia",
        "gie"
    ],
    "friday": [
        "venderdi",
        "ve"
    ],
    "saturday": [
        "sonda",
        "so"
    ],
    "sunday": [
        "dumengia",
        "du"
    ],
    "am": [
        "am"
    ],
    "pm": [
        "pm"
    ],
    "year": [
        "onn"
    ],
    "month": [
        "mais"
    ],
    "week": [
        "emna"
    ],
    "day": [
        "tag"
    ],
    "hour": [
        "ura"
    ],
    "minute": [
        "minuta"
    ],
    "second": [
        "secunda"
    ],
    "relative-type": {
        "1 year ago": [
            "last year"
        ],
        "0 year ago": [
            "this year"
        ],
        "in 1 year": [
            "next year"
        ],
        "1 month ago": [
            "last month"
        ],
        "0 month ago": [
            "this month"
        ],
        "in 1 month": [
            "next month"
        ],
        "1 week ago": [
            "last week"
        ],
        "0 week ago": [
            "this week"
        ],
        "in 1 week": [
            "next week"
        ],
        "1 day ago": [
            "ier"
        ],
        "0 day ago": [
            "oz"
        ],
        "in 1 day": [
            "damaun"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 second ago": [
            "now"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}



# -*- coding: utf-8 -*-
info = {
    "name": "ce",
    "date_order": "YMD",
    "january": [
        "январь",
        "янв"
    ],
    "february": [
        "февраль",
        "фев"
    ],
    "march": [
        "март",
        "мар"
    ],
    "april": [
        "апрель",
        "апр"
    ],
    "may": [
        "май"
    ],
    "june": [
        "июнь",
        "июн"
    ],
    "july": [
        "июль",
        "июл"
    ],
    "august": [
        "август",
        "авг"
    ],
    "september": [
        "сентябрь",
        "сен"
    ],
    "october": [
        "октябрь",
        "окт"
    ],
    "november": [
        "ноябрь",
        "ноя"
    ],
    "december": [
        "декабрь",
        "дек"
    ],
    "monday": [
        "оршотан де"
    ],
    "tuesday": [
        "шинарин де"
    ],
    "wednesday": [
        "кхаарин де"
    ],
    "thursday": [
        "еарин де"
    ],
    "friday": [
        "пӏераскан де"
    ],
    "saturday": [
        "шот де"
    ],
    "sunday": [
        "кӏиранан де"
    ],
    "am": [
        "am"
    ],
    "pm": [
        "pm"
    ],
    "year": [
        "шо",
        "ш"
    ],
    "month": [
        "бутт",
        "бут"
    ],
    "week": [
        "кӏира",
        "кӏир"
    ],
    "day": [
        "де"
    ],
    "hour": [
        "сахьт",
        "сахь"
    ],
    "minute": [
        "минот",
        "мин"
    ],
    "second": [
        "секунд",
        "сек"
    ],
    "relative-type": {
        "1 year ago": [
            "даханчу шарахь"
        ],
        "0 year ago": [
            "карарчу шарахь"
        ],
        "in 1 year": [
            "рогӏерчу шарахь"
        ],
        "1 month ago": [
            "баханчу баттахь"
        ],
        "0 month ago": [
            "карарчу баттахь"
        ],
        "in 1 month": [
            "рогӏерчу баттахь"
        ],
        "1 week ago": [
            "даханчу кӏирнахь"
        ],
        "0 week ago": [
            "карарчу кӏирнахь"
        ],
        "in 1 week": [
            "рогӏерчу кӏирнахь"
        ],
        "1 day ago": [
            "селхана"
        ],
        "0 day ago": [
            "тахана"
        ],
        "in 1 day": [
            "кхана"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 second ago": [
            "now"
        ]
    },
    "relative-type-regex": {
        "in \\1 year": [
            "(\\d+) шо даьлча",
            "(\\d+) ш даьлча"
        ],
        "\\1 year ago": [
            "(\\d+) шо хьалха",
            "(\\d+) ш хьалха"
        ],
        "in \\1 month": [
            "(\\d+) бутт баьлча",
            "(\\d+) б баьлча"
        ],
        "\\1 month ago": [
            "(\\d+) бутт хьалха",
            "(\\d+) б хьалха"
        ],
        "in \\1 week": [
            "(\\d+) кӏира даьлча",
            "(\\d+) кӏир даьлча"
        ],
        "\\1 week ago": [
            "(\\d+) кӏира хьалха",
            "(\\d+) кӏир хьалха"
        ],
        "in \\1 day": [
            "(\\d+) де даьлча",
            "(\\d+) д даьлча"
        ],
        "\\1 day ago": [
            "(\\d+) де хьалха",
            "(\\d+) д хьалха"
        ],
        "in \\1 hour": [
            "(\\d+) сахьт даьлча",
            "(\\d+) сахь даьлча"
        ],
        "\\1 hour ago": [
            "(\\d+) сахьт хьалха",
            "(\\d+) сахь хьалха"
        ],
        "in \\1 minute": [
            "(\\d+) минот яьлча",
            "(\\d+) мин яьлча"
        ],
        "\\1 minute ago": [
            "(\\d+) минот хьалха",
            "(\\d+) мин хьалха"
        ],
        "in \\1 second": [
            "(\\d+) секунд яьлча",
            "(\\d+) сек яьлча"
        ],
        "\\1 second ago": [
            "(\\d+) секунд хьалха",
            "(\\d+) сек хьалха"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}



# -*- coding: utf-8 -*-
info = {
    "name": "bs-Latn",
    "date_order": "DMY",
    "january": [
        "januar",
        "jan"
    ],
    "february": [
        "februar",
        "feb"
    ],
    "march": [
        "mart",
        "mar"
    ],
    "april": [
        "april",
        "apr"
    ],
    "may": [
        "maj"
    ],
    "june": [
        "juni",
        "jun"
    ],
    "july": [
        "juli",
        "jul"
    ],
    "august": [
        "avgust",
        "avg"
    ],
    "september": [
        "septembar",
        "sep"
    ],
    "october": [
        "oktobar",
        "okt"
    ],
    "november": [
        "novembar",
        "nov"
    ],
    "december": [
        "decembar",
        "dec"
    ],
    "monday": [
        "ponedjeljak",
        "pon"
    ],
    "tuesday": [
        "utorak",
        "uto"
    ],
    "wednesday": [
        "srijeda",
        "sri"
    ],
    "thursday": [
        "četvrtak",
        "čet"
    ],
    "friday": [
        "petak",
        "pet"
    ],
    "saturday": [
        "subota",
        "sub"
    ],
    "sunday": [
        "nedjelja",
        "ned"
    ],
    "am": [
        "prijepodne"
    ],
    "pm": [
        "popodne"
    ],
    "year": [
        "godina",
        "god",
        "g"
    ],
    "month": [
        "mjesec",
        "mj"
    ],
    "week": [
        "sedmica",
        "sed"
    ],
    "day": [
        "dan"
    ],
    "hour": [
        "sat",
        "h"
    ],
    "minute": [
        "minuta",
        "min"
    ],
    "second": [
        "sekunda",
        "sek",
        "s"
    ],
    "relative-type": {
        "1 year ago": [
            "prošle godine"
        ],
        "0 year ago": [
            "ove godine"
        ],
        "in 1 year": [
            "sljedeće godine"
        ],
        "1 month ago": [
            "prošli mjesec"
        ],
        "0 month ago": [
            "ovaj mjesec"
        ],
        "in 1 month": [
            "sljedeći mjesec"
        ],
        "1 week ago": [
            "prošle sedmice"
        ],
        "0 week ago": [
            "ove sedmice"
        ],
        "in 1 week": [
            "sljedeće sedmice"
        ],
        "1 day ago": [
            "jučer"
        ],
        "0 day ago": [
            "danas"
        ],
        "in 1 day": [
            "sutra"
        ],
        "0 hour ago": [
            "ovaj sat"
        ],
        "0 minute ago": [
            "ova minuta"
        ],
        "0 second ago": [
            "sada"
        ]
    },
    "relative-type-regex": {
        "in \\1 year": [
            "za (\\d+) godinu",
            "za (\\d+) godina",
            "za (\\d+) god",
            "za (\\d+) g"
        ],
        "\\1 year ago": [
            "prije (\\d+) godinu",
            "prije (\\d+) godina",
            "prije (\\d+) god",
            "prije (\\d+) g"
        ],
        "in \\1 month": [
            "za (\\d+) mjesec",
            "za (\\d+) mjeseci",
            "za (\\d+) mj"
        ],
        "\\1 month ago": [
            "prije (\\d+) mjesec",
            "prije (\\d+) mjeseci",
            "prije (\\d+) mj"
        ],
        "in \\1 week": [
            "za (\\d+) sedmicu",
            "za (\\d+) sedmica",
            "za (\\d+) sed"
        ],
        "\\1 week ago": [
            "prije (\\d+) sedmicu",
            "prije (\\d+) sedmica",
            "prije (\\d+) sed"
        ],
        "in \\1 day": [
            "za (\\d+) dan",
            "za (\\d+) dana",
            "za (\\d+) d"
        ],
        "\\1 day ago": [
            "prije (\\d+) dan",
            "prije (\\d+) dana",
            "prije (\\d+) d"
        ],
        "in \\1 hour": [
            "za (\\d+) sat",
            "za (\\d+) sati"
        ],
        "\\1 hour ago": [
            "prije (\\d+) sat",
            "prije (\\d+) sati"
        ],
        "in \\1 minute": [
            "za (\\d+) minutu",
            "za (\\d+) minuta",
            "za (\\d+) min"
        ],
        "\\1 minute ago": [
            "prije (\\d+) minutu",
            "prije (\\d+) minuta",
            "prije (\\d+) min"
        ],
        "in \\1 second": [
            "za (\\d+) sekundu",
            "za (\\d+) sekundi",
            "za (\\d+) sek"
        ],
        "\\1 second ago": [
            "prije (\\d+) sekundu",
            "prije (\\d+) sekundi",
            "prije (\\d+) sek"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}



# -*- coding: utf-8 -*-
info = {
    "name": "dav",
    "date_order": "DMY",
    "january": [
        "mori ghwa imbiri",
        "imb"
    ],
    "february": [
        "mori ghwa kawi",
        "kaw"
    ],
    "march": [
        "mori ghwa kadadu",
        "kad"
    ],
    "april": [
        "mori ghwa kana",
        "kan"
    ],
    "may": [
        "mori ghwa kasanu",
        "kas"
    ],
    "june": [
        "mori ghwa karandadu",
        "kar"
    ],
    "july": [
        "mori ghwa mfungade",
        "mfu"
    ],
    "august": [
        "mori ghwa wunyanya",
        "wun"
    ],
    "september": [
        "mori ghwa ikenda",
        "ike"
    ],
    "october": [
        "mori ghwa ikumi",
        "iku"
    ],
    "november": [
        "mori ghwa ikumi na imweri",
        "imw"
    ],
    "december": [
        "mori ghwa ikumi na iwi",
        "iwi"
    ],
    "monday": [
        "kuramuka jimweri",
        "jim"
    ],
    "tuesday": [
        "kuramuka kawi",
        "kaw"
    ],
    "wednesday": [
        "kuramuka kadadu",
        "kad"
    ],
    "thursday": [
        "kuramuka kana",
        "kan"
    ],
    "friday": [
        "kuramuka kasanu",
        "kas"
    ],
    "saturday": [
        "kifula nguwo",
        "ngu"
    ],
    "sunday": [
        "ituku ja jumwa",
        "jum"
    ],
    "am": [
        "luma lwa k"
    ],
    "pm": [
        "luma lwa p"
    ],
    "year": [
        "mwaka"
    ],
    "month": [
        "mori"
    ],
    "week": [
        "juma"
    ],
    "day": [
        "ituku"
    ],
    "hour": [
        "saa"
    ],
    "minute": [
        "dakika"
    ],
    "second": [
        "sekunde"
    ],
    "relative-type": {
        "1 year ago": [
            "last year"
        ],
        "0 year ago": [
            "this year"
        ],
        "in 1 year": [
            "next year"
        ],
        "1 month ago": [
            "last month"
        ],
        "0 month ago": [
            "this month"
        ],
        "in 1 month": [
            "next month"
        ],
        "1 week ago": [
            "last week"
        ],
        "0 week ago": [
            "this week"
        ],
        "in 1 week": [
            "next week"
        ],
        "1 day ago": [
            "iguo"
        ],
        "0 day ago": [
            "idime"
        ],
        "in 1 day": [
            "kesho"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 second ago": [
            "now"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}



# -*- coding: utf-8 -*-
info = {
    "name": "kl",
    "date_order": "YMD",
    "january": [
        "januari",
        "jan"
    ],
    "february": [
        "februari",
        "feb"
    ],
    "march": [
        "martsi",
        "mar"
    ],
    "april": [
        "aprili",
        "apr"
    ],
    "may": [
        "maji",
        "maj"
    ],
    "june": [
        "juni",
        "jun"
    ],
    "july": [
        "juli",
        "jul"
    ],
    "august": [
        "augustusi",
        "aug"
    ],
    "september": [
        "septemberi",
        "sep"
    ],
    "october": [
        "oktoberi",
        "okt"
    ],
    "november": [
        "novemberi",
        "nov"
    ],
    "december": [
        "decemberi",
        "dec"
    ],
    "monday": [
        "ataasinngorneq",
        "ata"
    ],
    "tuesday": [
        "marlunngorneq",
        "mar"
    ],
    "wednesday": [
        "pingasunngorneq",
        "pin"
    ],
    "thursday": [
        "sisamanngorneq",
        "sis"
    ],
    "friday": [
        "tallimanngorneq",
        "tal"
    ],
    "saturday": [
        "arfininngorneq",
        "arf"
    ],
    "sunday": [
        "sabaat",
        "sab"
    ],
    "am": [
        "am"
    ],
    "pm": [
        "pm"
    ],
    "year": [
        "year"
    ],
    "month": [
        "month"
    ],
    "week": [
        "week"
    ],
    "day": [
        "day"
    ],
    "hour": [
        "hour"
    ],
    "minute": [
        "minute"
    ],
    "second": [
        "second"
    ],
    "relative-type": {
        "1 year ago": [
            "last year"
        ],
        "0 year ago": [
            "this year"
        ],
        "in 1 year": [
            "next year"
        ],
        "1 month ago": [
            "last month"
        ],
        "0 month ago": [
            "this month"
        ],
        "in 1 month": [
            "next month"
        ],
        "1 week ago": [
            "last week"
        ],
        "0 week ago": [
            "this week"
        ],
        "in 1 week": [
            "next week"
        ],
        "1 day ago": [
            "yesterday"
        ],
        "0 day ago": [
            "today"
        ],
        "in 1 day": [
            "tomorrow"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 second ago": [
            "now"
        ]
    },
    "relative-type-regex": {
        "in \\1 year": [
            "om (\\d+) ukioq"
        ],
        "\\1 year ago": [
            "for (\\d+) ukioq siden"
        ],
        "in \\1 month": [
            "om (\\d+) qaammat"
        ],
        "\\1 month ago": [
            "for (\\d+) qaammat siden"
        ],
        "in \\1 week": [
            "om (\\d+) sapaatip-akunnera"
        ],
        "\\1 week ago": [
            "for (\\d+) sapaatip-akunnera siden"
        ],
        "in \\1 day": [
            "om (\\d+) ulloq unnuarlu"
        ],
        "\\1 day ago": [
            "for (\\d+) ulloq unnuarlu siden"
        ],
        "in \\1 hour": [
            "om (\\d+) nalunaaquttap-akunnera"
        ],
        "\\1 hour ago": [
            "for (\\d+) nalunaaquttap-akunnera siden"
        ],
        "in \\1 minute": [
            "om (\\d+) minutsi"
        ],
        "\\1 minute ago": [
            "for (\\d+) minutsi siden"
        ],
        "in \\1 second": [
            "om (\\d+) sekundi"
        ],
        "\\1 second ago": [
            "for (\\d+) sekundi siden"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}



# -*- coding: utf-8 -*-
info = {
    "name": "wae",
    "date_order": "YMD",
    "january": [
        "jenner",
        "jen"
    ],
    "february": [
        "hornig",
        "hor"
    ],
    "march": [
        "märze",
        "mär"
    ],
    "april": [
        "abrille",
        "abr"
    ],
    "may": [
        "meije",
        "mei"
    ],
    "june": [
        "bráčet",
        "brá"
    ],
    "july": [
        "heiwet",
        "hei"
    ],
    "august": [
        "öigšte",
        "öig"
    ],
    "september": [
        "herbštmánet",
        "her"
    ],
    "october": [
        "wímánet",
        "wím"
    ],
    "november": [
        "wintermánet",
        "win"
    ],
    "december": [
        "chrištmánet",
        "chr"
    ],
    "monday": [
        "mäntag",
        "män"
    ],
    "tuesday": [
        "zištag",
        "ziš"
    ],
    "wednesday": [
        "mittwuč",
        "mit"
    ],
    "thursday": [
        "fróntag",
        "fró"
    ],
    "friday": [
        "fritag",
        "fri"
    ],
    "saturday": [
        "samštag",
        "sam"
    ],
    "sunday": [
        "sunntag",
        "sun"
    ],
    "am": [
        "am"
    ],
    "pm": [
        "pm"
    ],
    "year": [
        "jár"
    ],
    "month": [
        "mánet"
    ],
    "week": [
        "wuča"
    ],
    "day": [
        "tag"
    ],
    "hour": [
        "schtund"
    ],
    "minute": [
        "mínütta"
    ],
    "second": [
        "sekunda"
    ],
    "relative-type": {
        "1 year ago": [
            "last year"
        ],
        "0 year ago": [
            "this year"
        ],
        "in 1 year": [
            "next year"
        ],
        "1 month ago": [
            "last month"
        ],
        "0 month ago": [
            "this month"
        ],
        "in 1 month": [
            "next month"
        ],
        "1 week ago": [
            "last week"
        ],
        "0 week ago": [
            "this week"
        ],
        "in 1 week": [
            "next week"
        ],
        "1 day ago": [
            "gešter"
        ],
        "0 day ago": [
            "hitte"
        ],
        "in 1 day": [
            "móre"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 second ago": [
            "now"
        ]
    },
    "relative-type-regex": {
        "in \\1 year": [
            "i (\\d+) jár"
        ],
        "\\1 year ago": [
            "vor (\\d+) jár",
            "cor (\\d+) jár"
        ],
        "in \\1 month": [
            "i (\\d+) mánet"
        ],
        "\\1 month ago": [
            "vor (\\d+) mánet"
        ],
        "in \\1 week": [
            "i (\\d+) wuča",
            "i (\\d+) wučä"
        ],
        "\\1 week ago": [
            "vor (\\d+) wuča",
            "cor (\\d+) wučä"
        ],
        "in \\1 day": [
            "i (\\d+) tag",
            "i (\\d+) täg"
        ],
        "\\1 day ago": [
            "vor (\\d+) tag",
            "vor (\\d+) täg"
        ],
        "in \\1 hour": [
            "i (\\d+) stund",
            "i (\\d+) stunde"
        ],
        "\\1 hour ago": [
            "vor (\\d+) stund",
            "vor (\\d+) stunde"
        ],
        "in \\1 minute": [
            "i (\\d+) minüta",
            "i (\\d+) minüte"
        ],
        "\\1 minute ago": [
            "vor (\\d+) minüta",
            "vor (\\d+) minüte"
        ],
        "in \\1 second": [
            "i (\\d+) sekund",
            "i (\\d+) sekunde"
        ],
        "\\1 second ago": [
            "vor (\\d+) sekund",
            "vor (\\d+) sekunde"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}



# -*- coding: utf-8 -*-
info = {
    "name": "kk",
    "date_order": "DMY",
    "january": [
        "қаңтар",
        "қаң"
    ],
    "february": [
        "ақпан",
        "ақп"
    ],
    "march": [
        "наурыз",
        "нау"
    ],
    "april": [
        "сәуір",
        "сәу"
    ],
    "may": [
        "мамыр",
        "мам"
    ],
    "june": [
        "маусым",
        "мау"
    ],
    "july": [
        "шілде",
        "шіл"
    ],
    "august": [
        "тамыз",
        "там"
    ],
    "september": [
        "қыркүйек",
        "қыр"
    ],
    "october": [
        "қазан",
        "қаз"
    ],
    "november": [
        "қараша",
        "қар"
    ],
    "december": [
        "желтоқсан",
        "жел"
    ],
    "monday": [
        "дүйсенбі",
        "дс"
    ],
    "tuesday": [
        "сейсенбі",
        "сс"
    ],
    "wednesday": [
        "сәрсенбі",
        "ср"
    ],
    "thursday": [
        "бейсенбі",
        "бс"
    ],
    "friday": [
        "жұма",
        "жм"
    ],
    "saturday": [
        "сенбі",
        "сб"
    ],
    "sunday": [
        "жексенбі",
        "жс"
    ],
    "am": [
        "am"
    ],
    "pm": [
        "pm"
    ],
    "year": [
        "жыл",
        "ж"
    ],
    "month": [
        "ай"
    ],
    "week": [
        "апта",
        "ап"
    ],
    "day": [
        "күн"
    ],
    "hour": [
        "сағат",
        "сағ"
    ],
    "minute": [
        "минут",
        "мин"
    ],
    "second": [
        "секунд",
        "с"
    ],
    "relative-type": {
        "1 year ago": [
            "былтырғы жыл"
        ],
        "0 year ago": [
            "биылғы жыл"
        ],
        "in 1 year": [
            "келесі жыл"
        ],
        "1 month ago": [
            "өткен ай"
        ],
        "0 month ago": [
            "осы ай"
        ],
        "in 1 month": [
            "келесі ай"
        ],
        "1 week ago": [
            "өткен апта"
        ],
        "0 week ago": [
            "осы апта"
        ],
        "in 1 week": [
            "келесі апта"
        ],
        "1 day ago": [
            "кеше"
        ],
        "0 day ago": [
            "бүгін"
        ],
        "in 1 day": [
            "ертең"
        ],
        "0 hour ago": [
            "осы сағат"
        ],
        "0 minute ago": [
            "осы минут"
        ],
        "0 second ago": [
            "қазір"
        ]
    },
    "relative-type-regex": {
        "in \\1 year": [
            "(\\d+) жылдан кейін",
            "(\\d+) ж кейін"
        ],
        "\\1 year ago": [
            "(\\d+) жыл бұрын",
            "(\\d+) ж бұрын"
        ],
        "in \\1 month": [
            "(\\d+) айдан кейін"
        ],
        "\\1 month ago": [
            "(\\d+) ай бұрын"
        ],
        "in \\1 week": [
            "(\\d+) аптадан кейін",
            "(\\d+) ап кейін"
        ],
        "\\1 week ago": [
            "(\\d+) апта бұрын",
            "(\\d+) ап бұрын"
        ],
        "in \\1 day": [
            "(\\d+) күннен кейін"
        ],
        "\\1 day ago": [
            "(\\d+) күн бұрын"
        ],
        "in \\1 hour": [
            "(\\d+) сағаттан кейін",
            "(\\d+) сағ кейін"
        ],
        "\\1 hour ago": [
            "(\\d+) сағат бұрын",
            "(\\d+) сағ бұрын"
        ],
        "in \\1 minute": [
            "(\\d+) минуттан кейін",
            "(\\d+) мин кейін"
        ],
        "\\1 minute ago": [
            "(\\d+) минут бұрын",
            "(\\d+) мин бұрын"
        ],
        "in \\1 second": [
            "(\\d+) секундтан кейін",
            "(\\d+) сек кейін"
        ],
        "\\1 second ago": [
            "(\\d+) секунд бұрын",
            "(\\d+) сек бұрын"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}



# -*- coding: utf-8 -*-
info = {
    "name": "gd",
    "date_order": "DMY",
    "january": [
        "am faoilleach",
        "faoi",
        "dhen fhaoilleach"
    ],
    "february": [
        "an gearran",
        "gearr",
        "dhen ghearran"
    ],
    "march": [
        "am màrt",
        "màrt",
        "dhen mhàrt"
    ],
    "april": [
        "an giblean",
        "gibl",
        "dhen ghiblean"
    ],
    "may": [
        "an cèitean",
        "cèit",
        "dhen chèitean"
    ],
    "june": [
        "an t-ògmhios",
        "ògmh",
        "dhen ògmhios"
    ],
    "july": [
        "an t-iuchar",
        "iuch",
        "dhen iuchar"
    ],
    "august": [
        "an lùnastal",
        "lùna",
        "dhen lùnastal"
    ],
    "september": [
        "an t-sultain",
        "sult",
        "dhen t-sultain"
    ],
    "october": [
        "an dàmhair",
        "dàmh",
        "dhen dàmhair"
    ],
    "november": [
        "an t-samhain",
        "samh",
        "dhen t-samhain"
    ],
    "december": [
        "an dùbhlachd",
        "dùbh",
        "dhen dùbhlachd"
    ],
    "monday": [
        "diluain",
        "dil"
    ],
    "tuesday": [
        "dimàirt",
        "dim"
    ],
    "wednesday": [
        "diciadain",
        "dic"
    ],
    "thursday": [
        "diardaoin",
        "dia"
    ],
    "friday": [
        "dihaoine",
        "dih"
    ],
    "saturday": [
        "disathairne",
        "dis"
    ],
    "sunday": [
        "didòmhnaich",
        "did"
    ],
    "am": [
        "m"
    ],
    "pm": [
        "f"
    ],
    "year": [
        "bliadhna",
        "blia",
        "bl"
    ],
    "month": [
        "mìos",
        "mì"
    ],
    "week": [
        "seachdain",
        "seachd",
        "sn"
    ],
    "day": [
        "latha",
        "là"
    ],
    "hour": [
        "uair a thìde",
        "uair",
        "u"
    ],
    "minute": [
        "mionaid",
        "mion",
        "m"
    ],
    "second": [
        "diog",
        "d"
    ],
    "relative-type": {
        "1 year ago": [
            "an-uiridh",
            "an-uir"
        ],
        "0 year ago": [
            "am bliadhna",
            "am bl"
        ],
        "in 1 year": [
            "an ath-bhliadhna",
            "an ath-bhl"
        ],
        "1 month ago": [
            "am mìos seo chaidh",
            "am mìos sa chaidh",
            "mì ch"
        ],
        "0 month ago": [
            "am mìos seo",
            "am mì seo"
        ],
        "in 1 month": [
            "an ath-mhìos",
            "ath-mhì"
        ],
        "1 week ago": [
            "an t-seachdain seo chaidh",
            "seachd sa chaidh",
            "sn ch"
        ],
        "0 week ago": [
            "an t-seachdain seo",
            "an t-seachd seo",
            "an t-sn seo"
        ],
        "in 1 week": [
            "an ath-sheachdain",
            "an ath-sheachd",
            "ath-shn"
        ],
        "1 day ago": [
            "an-dè"
        ],
        "0 day ago": [
            "an-diugh"
        ],
        "in 1 day": [
            "a-màireach"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 second ago": [
            "an-dràsta"
        ]
    },
    "relative-type-regex": {
        "in \\1 year": [
            "an ceann (\\d+) bhliadhna",
            "an ceann (\\d+) bliadhna",
            "an (\\d+) bhlia",
            "an (\\d+) blia"
        ],
        "\\1 year ago": [
            "(\\d+) bhliadhna air ais",
            "(\\d+) bliadhna air ais",
            "o (\\d+) bhlia",
            "o (\\d+) blia"
        ],
        "in \\1 month": [
            "an ceann (\\d+) mhìosa",
            "an ceann (\\d+) mìosa",
            "an (\\d+) mhìos",
            "an (\\d+) mìos"
        ],
        "\\1 month ago": [
            "(\\d+) mhìos air ais",
            "(\\d+) mìos air ais",
            "o (\\d+) mhìos",
            "o (\\d+) mìos"
        ],
        "in \\1 week": [
            "an ceann (\\d+) seachdain",
            "an (\\d+) sheachd",
            "an (\\d+) seachd"
        ],
        "\\1 week ago": [
            "(\\d+) seachdain air ais",
            "o (\\d+) sheachd",
            "o (\\d+) seachd"
        ],
        "in \\1 day": [
            "an ceann (\\d+) latha",
            "an (\\d+) là"
        ],
        "\\1 day ago": [
            "(\\d+) latha air ais",
            "o (\\d+) là"
        ],
        "in \\1 hour": [
            "an ceann (\\d+) uair a thìde",
            "an (\\d+) uair"
        ],
        "\\1 hour ago": [
            "(\\d+) uair a thìde air ais",
            "o (\\d+) uair"
        ],
        "in \\1 minute": [
            "an ceann (\\d+) mhionaid",
            "an ceann (\\d+) mionaid",
            "an (\\d+) mhion",
            "an (\\d+) mion"
        ],
        "\\1 minute ago": [
            "(\\d+) mhionaid air ais",
            "(\\d+) mionaid air ais",
            "o (\\d+) mhion",
            "o (\\d+) mion"
        ],
        "in \\1 second": [
            "an ceann (\\d+) diog",
            "an (\\d+) diog"
        ],
        "\\1 second ago": [
            "(\\d+) diog air ais",
            "o (\\d+) diog"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}



# -*- coding: utf-8 -*-
info = {
    "name": "sr-Latn",
    "date_order": "DMY",
    "january": [
        "januar",
        "jan"
    ],
    "february": [
        "februar",
        "feb"
    ],
    "march": [
        "mart",
        "mar"
    ],
    "april": [
        "april",
        "apr"
    ],
    "may": [
        "maj"
    ],
    "june": [
        "jun"
    ],
    "july": [
        "jul"
    ],
    "august": [
        "avgust",
        "avg"
    ],
    "september": [
        "septembar",
        "sep"
    ],
    "october": [
        "oktobar",
        "okt"
    ],
    "november": [
        "novembar",
        "nov"
    ],
    "december": [
        "decembar",
        "dec"
    ],
    "monday": [
        "ponedeljak",
        "pon"
    ],
    "tuesday": [
        "utorak",
        "uto"
    ],
    "wednesday": [
        "sreda",
        "sre"
    ],
    "thursday": [
        "četvrtak",
        "čet"
    ],
    "friday": [
        "petak",
        "pet"
    ],
    "saturday": [
        "subota",
        "sub"
    ],
    "sunday": [
        "nedelja",
        "ned"
    ],
    "am": [
        "pre podne"
    ],
    "pm": [
        "po podne"
    ],
    "year": [
        "godina",
        "god",
        "g"
    ],
    "month": [
        "mesec",
        "mes",
        "m"
    ],
    "week": [
        "nedelja",
        "ned",
        "n"
    ],
    "day": [
        "dan",
        "d"
    ],
    "hour": [
        "sat",
        "č"
    ],
    "minute": [
        "minut",
        "min"
    ],
    "second": [
        "sekund",
        "sek",
        "s"
    ],
    "relative-type": {
        "1 year ago": [
            "prošle godine"
        ],
        "0 year ago": [
            "ove godine"
        ],
        "in 1 year": [
            "sledeće godine"
        ],
        "1 month ago": [
            "prošlog meseca"
        ],
        "0 month ago": [
            "ovog meseca"
        ],
        "in 1 month": [
            "sledećeg meseca"
        ],
        "1 week ago": [
            "prošle nedelje"
        ],
        "0 week ago": [
            "ove nedelje"
        ],
        "in 1 week": [
            "sledeće nedelje"
        ],
        "1 day ago": [
            "juče"
        ],
        "0 day ago": [
            "danas"
        ],
        "in 1 day": [
            "sutra"
        ],
        "0 hour ago": [
            "ovog sata"
        ],
        "0 minute ago": [
            "ovog minuta"
        ],
        "0 second ago": [
            "sada"
        ]
    },
    "relative-type-regex": {
        "in \\1 year": [
            "za (\\d+) godinu",
            "za (\\d+) godina",
            "za (\\d+) god",
            "za (\\d+) g"
        ],
        "\\1 year ago": [
            "pre (\\d+) godine",
            "pre (\\d+) godina",
            "pre (\\d+) god",
            "pre (\\d+) g"
        ],
        "in \\1 month": [
            "za (\\d+) mesec",
            "za (\\d+) meseci",
            "za (\\d+) mes",
            "za (\\d+) m"
        ],
        "\\1 month ago": [
            "pre (\\d+) meseca",
            "pre (\\d+) meseci",
            "pre (\\d+) mes",
            "pre (\\d+) m"
        ],
        "in \\1 week": [
            "za (\\d+) nedelju",
            "za (\\d+) nedelja",
            "za (\\d+) ned",
            "za (\\d+) n"
        ],
        "\\1 week ago": [
            "pre (\\d+) nedelje",
            "pre (\\d+) nedelja",
            "pre (\\d+) ned",
            "pre (\\d+) n"
        ],
        "in \\1 day": [
            "za (\\d+) dan",
            "za (\\d+) dana",
            "za (\\d+) d"
        ],
        "\\1 day ago": [
            "pre (\\d+) dana",
            "pre (\\d+) d"
        ],
        "in \\1 hour": [
            "za (\\d+) sat",
            "za (\\d+) sati",
            "za (\\d+) č"
        ],
        "\\1 hour ago": [
            "pre (\\d+) sata",
            "pre (\\d+) sati",
            "pre (\\d+) č"
        ],
        "in \\1 minute": [
            "za (\\d+) minut",
            "za (\\d+) minuta",
            "za (\\d+) min"
        ],
        "\\1 minute ago": [
            "pre (\\d+) minuta",
            "pre (\\d+) min"
        ],
        "in \\1 second": [
            "za (\\d+) sekundu",
            "za (\\d+) sekundi",
            "za (\\d+) sek",
            "za (\\d+) s"
        ],
        "\\1 second ago": [
            "pre (\\d+) sekunde",
            "pre (\\d+) sekundi",
            "pre (\\d+) sek",
            "pre (\\d+) s"
        ]
    },
    "locale_specific": {
        "sr-Latn-XK": {
            "name": "sr-Latn-XK",
            "september": [
                "sept"
            ],
            "tuesday": [
                "ut"
            ],
            "wednesday": [
                "sr"
            ]
        },
        "sr-Latn-ME": {
            "name": "sr-Latn-ME",
            "september": [
                "sept"
            ],
            "tuesday": [
                "ut"
            ],
            "wednesday": [
                "srijeda",
                "sr"
            ],
            "sunday": [
                "nedjelja"
            ],
            "am": [
                "prije podne"
            ]
        },
        "sr-Latn-BA": {
            "name": "sr-Latn-BA",
            "september": [
                "sept"
            ],
            "tuesday": [
                "ut"
            ],
            "wednesday": [
                "srijeda",
                "sr"
            ],
            "sunday": [
                "nedjelja"
            ],
            "am": [
                "prije podne"
            ]
        }
    },
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}



# -*- coding: utf-8 -*-
info = {
    "name": "sr",
    "date_order": "DMY",
    "january": [
        "јануар",
        "јан"
    ],
    "february": [
        "фебруар",
        "феб"
    ],
    "march": [
        "март",
        "мар"
    ],
    "april": [
        "април",
        "апр"
    ],
    "may": [
        "мај"
    ],
    "june": [
        "јун"
    ],
    "july": [
        "јул"
    ],
    "august": [
        "август",
        "авг"
    ],
    "september": [
        "септембар",
        "сеп"
    ],
    "october": [
        "октобар",
        "окт"
    ],
    "november": [
        "новембар",
        "нов"
    ],
    "december": [
        "децембар",
        "дец"
    ],
    "monday": [
        "понедељак",
        "пон"
    ],
    "tuesday": [
        "уторак",
        "уто"
    ],
    "wednesday": [
        "среда",
        "сре"
    ],
    "thursday": [
        "четвртак",
        "чет"
    ],
    "friday": [
        "петак",
        "пет"
    ],
    "saturday": [
        "субота",
        "суб"
    ],
    "sunday": [
        "недеља",
        "нед"
    ],
    "am": [
        "пре подне"
    ],
    "pm": [
        "по подне"
    ],
    "year": [
        "година",
        "год",
        "г"
    ],
    "month": [
        "месец",
        "мес",
        "м"
    ],
    "week": [
        "недеља",
        "нед",
        "н"
    ],
    "day": [
        "дан",
        "д"
    ],
    "hour": [
        "сат",
        "ч"
    ],
    "minute": [
        "минут",
        "мин"
    ],
    "second": [
        "секунд",
        "сек",
        "с"
    ],
    "relative-type": {
        "1 year ago": [
            "прошле године"
        ],
        "0 year ago": [
            "ове године"
        ],
        "in 1 year": [
            "следеће године"
        ],
        "1 month ago": [
            "прошлог месеца"
        ],
        "0 month ago": [
            "овог месеца"
        ],
        "in 1 month": [
            "следећег месеца"
        ],
        "1 week ago": [
            "прошле недеље"
        ],
        "0 week ago": [
            "ове недеље"
        ],
        "in 1 week": [
            "следеће недеље"
        ],
        "1 day ago": [
            "јуче"
        ],
        "0 day ago": [
            "данас"
        ],
        "in 1 day": [
            "сутра"
        ],
        "0 hour ago": [
            "овог сата"
        ],
        "0 minute ago": [
            "овог минута"
        ],
        "0 second ago": [
            "сада"
        ]
    },
    "relative-type-regex": {
        "in \\1 year": [
            "за (\\d+) годину",
            "за (\\d+) година",
            "за (\\d+) год",
            "за (\\d+) г"
        ],
        "\\1 year ago": [
            "пре (\\d+) године",
            "пре (\\d+) година",
            "пре (\\d+) год",
            "пре (\\d+) г"
        ],
        "in \\1 month": [
            "за (\\d+) месец",
            "за (\\d+) месеци",
            "за (\\d+) мес",
            "за (\\d+) м"
        ],
        "\\1 month ago": [
            "пре (\\d+) месеца",
            "пре (\\d+) месеци",
            "пре (\\d+) мес",
            "пре (\\d+) м"
        ],
        "in \\1 week": [
            "за (\\d+) недељу",
            "за (\\d+) недеља",
            "за (\\d+) нед",
            "за (\\d+) н"
        ],
        "\\1 week ago": [
            "пре (\\d+) недеље",
            "пре (\\d+) недеља",
            "пре (\\d+) нед",
            "пре (\\d+) н"
        ],
        "in \\1 day": [
            "за (\\d+) дан",
            "за (\\d+) дана",
            "за (\\d+) д"
        ],
        "\\1 day ago": [
            "пре (\\d+) дана",
            "пре (\\d+) д"
        ],
        "in \\1 hour": [
            "за (\\d+) сат",
            "за (\\d+) сати",
            "за (\\d+) ч"
        ],
        "\\1 hour ago": [
            "пре (\\d+) сата",
            "пре (\\d+) сати",
            "пре (\\d+) ч"
        ],
        "in \\1 minute": [
            "за (\\d+) минут",
            "за (\\d+) минута",
            "за (\\d+) мин"
        ],
        "\\1 minute ago": [
            "пре (\\d+) минута",
            "пре (\\d+) мин"
        ],
        "in \\1 second": [
            "за (\\d+) секунду",
            "за (\\d+) секунди",
            "за (\\d+) сек",
            "за (\\d+) с"
        ],
        "\\1 second ago": [
            "пре (\\d+) секунде",
            "пре (\\d+) секунди",
            "пре (\\d+) сек",
            "пре (\\d+) с"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}



# -*- coding: utf-8 -*-
info = {
    "name": "ig",
    "date_order": "DMY",
    "january": [
        "jenụwarị",
        "jen"
    ],
    "february": [
        "febrụwarị",
        "feb"
    ],
    "march": [
        "maachị",
        "maa"
    ],
    "april": [
        "eprel",
        "epr"
    ],
    "may": [
        "mee"
    ],
    "june": [
        "juun",
        "juu"
    ],
    "july": [
        "julaị",
        "jul"
    ],
    "august": [
        "ọgọọst",
        "ọgọ"
    ],
    "september": [
        "septemba",
        "sep"
    ],
    "october": [
        "ọktoba",
        "ọkt"
    ],
    "november": [
        "novemba",
        "nov"
    ],
    "december": [
        "disemba",
        "dis"
    ],
    "monday": [
        "mọnde",
        "mọn"
    ],
    "tuesday": [
        "tiuzdee",
        "tiu"
    ],
    "wednesday": [
        "wenezdee",
        "wen"
    ],
    "thursday": [
        "tọọzdee",
        "tọọ"
    ],
    "friday": [
        "fraịdee",
        "fraị"
    ],
    "saturday": [
        "satọdee",
        "sat"
    ],
    "sunday": [
        "mbọsị ụka",
        "ụka"
    ],
    "am": [
        "am"
    ],
    "pm": [
        "pm"
    ],
    "year": [
        "afọ"
    ],
    "month": [
        "ọnwa"
    ],
    "week": [
        "izu"
    ],
    "day": [
        "ụbọchị"
    ],
    "hour": [
        "elekere"
    ],
    "minute": [
        "nkeji"
    ],
    "second": [
        "nkejinta"
    ],
    "relative-type": {
        "1 year ago": [
            "last year"
        ],
        "0 year ago": [
            "this year"
        ],
        "in 1 year": [
            "next year"
        ],
        "1 month ago": [
            "last month"
        ],
        "0 month ago": [
            "this month"
        ],
        "in 1 month": [
            "next month"
        ],
        "1 week ago": [
            "last week"
        ],
        "0 week ago": [
            "this week"
        ],
        "in 1 week": [
            "next week"
        ],
        "1 day ago": [
            "nnyaafụ"
        ],
        "0 day ago": [
            "taata"
        ],
        "in 1 day": [
            "echi"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 second ago": [
            "now"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}
